<!-- The Identity Transformation -->
<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:tei="http://www.tei-c.org/ns/1.0"
  xmlns:ns1="http://bfm.ens-lyon.fr/ns/1.0"
  xmlns:office="urn:oasis:names:tc:opendocument:xmlns:office:1.0"
  exclude-result-prefixes="#all">
  
  
  <!-- Whenever you match any node or any attribute -->
  <xsl:template match="*|comment()|processing-instruction()|@*">
    <!-- Copy the current node -->
    <xsl:copy>
      <!-- Including any attributes it has and any child nodes -->
      <xsl:apply-templates select="@*|node()"/>
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="processing-instruction('xml-model')"></xsl:template>
  <xsl:template match="processing-instruction('xml-stylesheet')"></xsl:template>
  <xsl:template match="processing-instruction('oxygen')"></xsl:template>
  
  <xsl:template match="@part"></xsl:template>

<xsl:template match="tei:teiHeader/@type"/>
  
  <xsl:template match="tei:teiHeader//tei:msPart">
    <xsl:apply-templates/>
  </xsl:template>

<xsl:template match="tei:msPart/tei:altIdentifier"/>
  
  <xsl:template match="tei:msIdentifier">
    <xsl:copy>
      <xsl:apply-templates select="node()|@*"/>
      <xsl:if test="following-sibling::tei:msPart">
        <xsl:copy-of select="following-sibling::tei:msPart[1]/tei:altIdentifier"></xsl:copy-of>
      </xsl:if>
    </xsl:copy>
  </xsl:template>

  
  <!--<xsl:template match="tei:w">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()"/>
    </xsl:copy>
  </xsl:template>-->
  
  <xsl:template match="tei:w/@ns1:aggl"></xsl:template>
  <xsl:template match="tei:w/@ns1:agglCert"></xsl:template>

<xsl:template match="text()">
  <xsl:choose>
    <xsl:when test="ancestor::tei:note|ancestor::tei:head">
      <xsl:call-template name="process-notes">
        <xsl:with-param name="string"><xsl:value-of select="."/></xsl:with-param>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="ex"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>
  
  <xsl:template name="process-notes">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:value-of select="$string"/>
  </xsl:template>

  


  <xsl:template name="ex">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:analyze-string select="$string" regex="#?#?\(\(([^\)]+)\)\)(#?\*?.*)">
      <xsl:matching-substring>
        
          
        <xsl:variable name="capitalize">
          <xsl:choose>
            <xsl:when test="matches(.,'^##')">norm</xsl:when>
            <xsl:when test="matches(.,'^#')">dipl</xsl:when>
            <xsl:otherwise>no</xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <xsl:variable name="nextLetter"><xsl:value-of select="regex-group(2)"/></xsl:variable>
        <xsl:variable name="abbrexpan">
          <xsl:value-of select="replace(regex-group(1),'#','')"/>
          <!--<xsl:value-of select="regex-group(1)"/>-->
        </xsl:variable>
        
        <xsl:variable name="abbr">
          <xsl:choose>
            <xsl:when test="matches($abbrexpan,'_')"><xsl:value-of select="substring-before($abbrexpan,'_')"/></xsl:when>
            <xsl:when test="matches($abbrexpan,'^#?(.&#x0305;|.&#x0363;|.&#x0364;|.&#x0365;|bn&#x0305;|ch&#x02BC;&#xA75B;|ch&#x0305;&#xA75B;|ch&#xA75B;&#x0305;|gn&#x0363;t|qn&#x0363;t|&#x035B;|&#x1DD1;|&#x204A;|&#x223B;|&#xA76F;|&#xA770;|&#xF153;|&#xF158;|&#xF1C8;)$')">
              <xsl:value-of select="$abbrexpan"/>
            </xsl:when>
            <xsl:otherwise>xxx</xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <xsl:variable name="expannocap" as="element()">
          <expan xmlns="http://www.tei-c.org/ns/1.0">
            <xsl:choose>
              <xsl:when test="matches($abbrexpan,'_')">
                <xsl:analyze-string select="substring-after($abbrexpan,'_')" regex="\[([^\]]+)\]">
                  <xsl:matching-substring>
                    <ex xmlns="http://www.tei-c.org/ns/1.0"><xsl:value-of select="regex-group(1)"/></ex>
                  </xsl:matching-substring>
                  <xsl:non-matching-substring>
                    <xsl:copy/>
                  </xsl:non-matching-substring>
                </xsl:analyze-string>
              </xsl:when>
              <xsl:when test="matches($abbrexpan,'^bn&#x0305;$')">b<ex xmlns="http://www.tei-c.org/ns/1.0">ie</ex>n</xsl:when>
              <xsl:when test="matches($abbrexpan,'^(ch&#x02BC;&#xA75B;|ch&#x0305;&#xA75B;|ch&#xA75B;&#x0305;)$')">ch<ex xmlns="http://www.tei-c.org/ns/1.0">evalie</ex>r</xsl:when>
              <xsl:when test="matches($abbrexpan,'gn&#x0363;t')">g<ex xmlns="http://www.tei-c.org/ns/1.0">r</ex><c xmlns="http://www.tei-c.org/ns/1.0" rend="position(combsup)">a</c>nt</xsl:when>
              <xsl:when test="matches($abbrexpan,'qn&#x0363;t')">q<ex xmlns="http://www.tei-c.org/ns/1.0">u</ex><c xmlns="http://www.tei-c.org/ns/1.0" rend="position(combsup)">a</c>nt</xsl:when>
              <xsl:when test="matches($abbrexpan,'.&#x0305;$')">
                <xsl:value-of select="substring($abbrexpan,1,1)"/>
                <xsl:choose>
                  <xsl:when test="matches($abbrexpan,'^[aeiou]') and matches($nextLetter,'[bmp]')"><ex xmlns="http://www.tei-c.org/ns/1.0">m</ex></xsl:when>
                  <xsl:when test="matches($abbrexpan,'^[aeiou]')"><ex xmlns="http://www.tei-c.org/ns/1.0">n</ex></xsl:when>
                  <xsl:when test="matches($abbrexpan,'^[q]')"><ex xmlns="http://www.tei-c.org/ns/1.0">ue</ex></xsl:when>
                  <xsl:when test="matches($abbrexpan,'^[p]')"><ex xmlns="http://www.tei-c.org/ns/1.0">re</ex></xsl:when>
                  <xsl:when test="matches($abbrexpan,'^[m]')"><ex xmlns="http://www.tei-c.org/ns/1.0">en</ex></xsl:when>
                  <xsl:otherwise>‹bar›</xsl:otherwise>
                </xsl:choose>
              </xsl:when>
              <xsl:when test="matches($abbrexpan,'.&#x0363;')">
                <xsl:value-of select="substring($abbrexpan,1,1)"/>
                <xsl:choose>
                  <xsl:when test="matches($abbrexpan,'^[Qq]')"><ex xmlns="http://www.tei-c.org/ns/1.0">u</ex></xsl:when>
                  <xsl:otherwise><ex xmlns="http://www.tei-c.org/ns/1.0">r</ex></xsl:otherwise>
                </xsl:choose>
                <xsl:text>a</xsl:text>
              </xsl:when>
              <xsl:when test="matches($abbrexpan,'.&#x0364;')">
                <xsl:value-of select="substring($abbrexpan,1,1)"/>
                <xsl:choose>
                  <xsl:when test="matches($abbrexpan,'^[Qq]')"><ex xmlns="http://www.tei-c.org/ns/1.0">u</ex></xsl:when>
                  <xsl:otherwise><ex xmlns="http://www.tei-c.org/ns/1.0">r</ex></xsl:otherwise>
                </xsl:choose>
                <xsl:text>e</xsl:text>
              </xsl:when>
              <xsl:when test="matches($abbrexpan,'.&#x0365;')">
                <xsl:value-of select="substring($abbrexpan,1,1)"/>
                <xsl:choose>
                  <xsl:when test="matches($abbrexpan,'^[Qq]')"><ex xmlns="http://www.tei-c.org/ns/1.0">u</ex></xsl:when>
                  <xsl:otherwise><ex xmlns="http://www.tei-c.org/ns/1.0">r</ex></xsl:otherwise>
                </xsl:choose>
                <xsl:text>i</xsl:text>
              </xsl:when>
              <xsl:when test="matches($abbrexpan,'&#xA76F;') and matches($nextLetter,'[bmp]')">
                <ex xmlns="http://www.tei-c.org/ns/1.0">com</ex>
              </xsl:when>
              <xsl:when test="matches($abbrexpan,'&#xA76F;')">
                <ex xmlns="http://www.tei-c.org/ns/1.0">con</ex>
              </xsl:when>
              <xsl:when test="matches($abbrexpan,'&#x035B;|&#xF1C8;')">
                <ex xmlns="http://www.tei-c.org/ns/1.0">er</ex>
              </xsl:when>
              <xsl:when test="matches($abbrexpan,'&#x204A;|&#xF158;')">
                <ex xmlns="http://www.tei-c.org/ns/1.0">et</ex>
              </xsl:when>
              <xsl:when test="matches($abbrexpan,'&#x1DD1;|&#xF153;')">
                <ex xmlns="http://www.tei-c.org/ns/1.0">ur</ex>
              </xsl:when>
              <xsl:when test="matches($abbrexpan,'&#xA770;')">
                <ex xmlns="http://www.tei-c.org/ns/1.0">us</ex>
              </xsl:when>
              <xsl:otherwise>
                <ex xmlns="http://www.tei-c.org/ns/1.0"><xsl:value-of select="$abbrexpan"/></ex><!--<xsl:comment>Unknown expan!</xsl:comment>-->
              </xsl:otherwise>
            </xsl:choose></expan>
        </xsl:variable>
        <xsl:variable name="expan">
          <xsl:choose>
            <xsl:when test="$capitalize eq 'norm'">
              <expan xmlns="http://www.tei-c.org/ns/1.0">
                <xsl:for-each select="$expannocap/node()">
                  <xsl:choose>
                    <xsl:when test="self::text()[not(preceding-sibling::*)]">
                      <xsl:value-of select="upper-case(substring(.,1,1))"/><xsl:value-of select="substring(.,2)"/>
                    </xsl:when>
                    <xsl:when test="self::*[not(preceding-sibling::text())]">
                      <xsl:copy><xsl:value-of select="upper-case(substring(.,1,1))"/><xsl:value-of select="substring(.,2)"/></xsl:copy>
                    </xsl:when>
                    <xsl:otherwise>
                      <!--<xsl:copy-of select="translate(.,'()','')"/>-->
                      <xsl:copy-of select="."/>
                    </xsl:otherwise>
                  </xsl:choose>
                </xsl:for-each>
              </expan>
            </xsl:when>
            <xsl:otherwise><xsl:copy-of select="$expannocap"/></xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <xsl:choose>
          <xsl:when test="matches($abbr,'.+')">
            <choice xmlns="http://www.tei-c.org/ns/1.0">
              <abbr xmlns="http://www.tei-c.org/ns/1.0"><xsl:copy-of select="$abbr"/></abbr>
              <xsl:copy-of select="$expan"/>
            </choice>
          </xsl:when>
          <xsl:otherwise><xsl:copy-of select="$expan"/><xsl:comment>Unknown abbr!</xsl:comment></xsl:otherwise>
        </xsl:choose>
        <xsl:call-template name="ex"><xsl:with-param name="string"><xsl:value-of select="$nextLetter"/></xsl:with-param></xsl:call-template>
      </xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:call-template name="lettrine"><xsl:with-param name="string"><xsl:value-of select="."/></xsl:with-param></xsl:call-template>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>


  <xsl:template name="lettrine">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:analyze-string select="$string" regex="\{{\{{([^\}}]+)\}}\}}">
      <xsl:matching-substring>
        <xsl:variable name="substring"><xsl:value-of select="replace(.,'[\{{\}}]','')"/></xsl:variable>
        <g xmlns="http://www.tei-c.org/ns/1.0" type="initiale">
          <xsl:analyze-string select="$substring" regex="^([^:]+):([^:]*):([^:]*):([^:]*)(:([^:]*))?$">
            <xsl:matching-substring>
              <xsl:attribute name="rend">
                <xsl:text>size(</xsl:text>
                <xsl:value-of select="regex-group(2)"/>
                <xsl:text>) sizeAct(</xsl:text>
                <xsl:value-of select="regex-group(3)"/>
                <xsl:text>) color(</xsl:text>
                <xsl:value-of select="regex-group(4)"/>
                <xsl:text>)</xsl:text>
                <xsl:if test="matches(regex-group(5),'\S')">
                  <xsl:text> decoration(</xsl:text>
                  <xsl:value-of select="regex-group(6)"/>
                  <xsl:text>)</xsl:text>
                </xsl:if>
              </xsl:attribute>
              <xsl:value-of select="regex-group(1)"/>
            </xsl:matching-substring>
            <xsl:non-matching-substring>
              <xsl:attribute name="rend">
                <xsl:value-of select="replace(.,'^(\*.)(.*)$','$2')"/>
              </xsl:attribute>
              <xsl:value-of select="replace(.,'^(\*.)(.*)$','$1')"/>
            </xsl:non-matching-substring>
          </xsl:analyze-string>
        </g>
      </xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:value-of select="."/>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
    
  </xsl:template> 



</xsl:stylesheet>
