<?xml version="1.0"?>
<xsl:stylesheet xmlns:edate="http://exslt.org/dates-and-times"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tei="http://www.tei-c.org/ns/1.0"
  exclude-result-prefixes="tei edate" xpath-default-namespace="http://www.tei-c.org/ns/1.0" version="2.0">

  <xsl:output method="xml" encoding="utf-8" omit-xml-declaration="no"/> 
  
  
<!-- Partie générale : on copie les éléments, les attributs, le texte, les commentaires, on supprime mes prrocessing intstructions -->
  
  <xsl:template match="*">      
        <xsl:copy>
          <xsl:apply-templates select="*|@*|processing-instruction()|comment()|text()"/>
        </xsl:copy>    
  </xsl:template>
  
  <xsl:template match="*" mode="position"><xsl:value-of select="count(preceding-sibling::*)"/></xsl:template>

  <xsl:template match="@*|comment()|processing-instruction()">
    <xsl:copy/>
  </xsl:template>

  <xsl:variable name="current-file-name">
    <xsl:analyze-string select="document-uri(.)" regex="^(.*)/([^/]+)\.[^/]+$">
      <xsl:matching-substring>
        <xsl:value-of select="regex-group(2)"/>
      </xsl:matching-substring>
    </xsl:analyze-string>
  </xsl:variable>
  
<!-- Métadonnées à récupérer -->
 
  
  <xsl:variable name="auteur">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/fileDesc/titleStmt/author">
        <xsl:for-each select="/TEI/teiHeader/fileDesc/titleStmt/author">
          <xsl:value-of select="."/>
          <xsl:if test="following-sibling::author">
            <xsl:text>, </xsl:text>
          </xsl:if>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>anonyme</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="datecompo">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/creation/date[@type='compo']">
        <xsl:choose>
          <xsl:when test="/TEI/teiHeader/profileDesc/creation/date[@type='compo'][1]/@when">
            <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[@type='compo'][1]/@when"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[@type='compo'][1]"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:when test="/TEI/teiHeader/profileDesc/creation/date">
        <xsl:choose>
          <xsl:when test="/TEI/teiHeader/profileDesc/creation/date[1]/@when">
            <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[1]/@when"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[1]"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>sans date</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="datecompolibre">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/creation/date[@type='compo']">
            <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[@type='compo'][1]"/>
      </xsl:when>
      <xsl:when test="/TEI/teiHeader/profileDesc/creation/date">
            <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[1]"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>sans date</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="deaf">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/biblFull/publicationStmt/idno[@type='sigle_DEAF']">
        <xsl:value-of select="/TEI/teiHeader/fileDesc/sourceDesc/biblFull/publicationStmt/idno[@type='sigle_DEAF']"/>
      </xsl:when>
      <xsl:otherwise>n/a</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="dialecte">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/creation/region[@type='dialecte_auteur']">
        <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/region[@type='dialecte_auteur']"/>
      </xsl:when>
      <xsl:otherwise>non vérifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="domaine">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/textClass/keywords/term[@type='domaine']">
        <xsl:value-of select="/TEI/teiHeader/profileDesc/textClass/keywords/term[@type='domaine']"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="edcomm">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/biblFull/publicationStmt/publisher">
        <xsl:value-of select="/TEI/teiHeader/fileDesc/sourceDesc/biblFull/publicationStmt/publisher"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="eddate">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/biblFull/publicationStmt/date">
        <xsl:value-of select="/TEI/teiHeader/fileDesc/sourceDesc/biblFull/publicationStmt/date"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="ednum">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/biblFull/editionStmt/edition">
        <xsl:value-of select="/TEI/teiHeader/fileDesc/sourceDesc/biblFull/editionStmt/edition"/>
      </xsl:when>
      <xsl:otherwise>n/a</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="edsci">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/biblFull/titleStmt/respStmt[contains(.,'Éditeur scientifique')]/name">
        <xsl:for-each select="/TEI/teiHeader/fileDesc/sourceDesc/biblFull/titleStmt/respStmt[contains(.,'Éditeur scientifique')]/name">
          <xsl:value-of select="."/>
          <xsl:if test="following-sibling::name">
            <xsl:text> ; </xsl:text>
          </xsl:if>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
 
  <xsl:variable name="edville">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/fileDesc/sourceDesc/biblFull/publicationStmt/pubPlace">
        <xsl:value-of select="/TEI/teiHeader/fileDesc/sourceDesc/biblFull/publicationStmt/pubPlace"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="forme">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/textClass/keywords/term[@type='forme']">
        <xsl:value-of select="/TEI/teiHeader/profileDesc/textClass/keywords/term[@type='forme']"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="genre">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader//keywords/term[@type='genre']">
        <xsl:value-of select="/TEI/teiHeader//keywords[1]/term[@type='genre'][1]"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>non spécifié</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="lemmatisation">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/revisionDesc/change[matches(.,'lemmatisation.*échantillon')]">
        <xsl:text>partiellement vérifiée</xsl:text>
      </xsl:when>
      <xsl:when test="/TEI/teiHeader/revisionDesc/change[matches(.,'lemmatisation')]">
        <xsl:text>vérifiée</xsl:text>
      </xsl:when>
      <xsl:otherwise>non vérifiée</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="morphosynt">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/revisionDesc/change[matches(.,'[eé]tiquetage morpho.*échantillon')]">
        <xsl:text>partiellement vérifié</xsl:text>
      </xsl:when>
      <xsl:when test="/TEI/teiHeader/revisionDesc/change[matches(.,'[eé]tiquetage morpho')]">
        <xsl:text>vérifié</xsl:text>
      </xsl:when>
      <xsl:otherwise>non vérifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="msdate">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/creation/date[@type='ms']/@when">
        <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[@type='ms']/@when"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="msdatelibre">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/creation/date[@type='ms']">
        <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[@type='ms']"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="msnotafter">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/creation/date[@type='ms']/@notAfter">
        <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[@type='ms']/@notAfter"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="msnotbefore">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/creation/date[@type='ms']/@notBefore">
        <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[@type='ms']/@notBefore"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="notafter">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/creation/date[@type='compo']/@notAfter">
        <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[@type='compo']/@notAfter"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="notbefore">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/creation/date[@type='compo']/@notBefore">
        <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[@type='compo']/@notBefore"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="relation">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/textClass/keywords/term[@type='relation']">
        <xsl:value-of select="/TEI/teiHeader/profileDesc/textClass/keywords/term[@type='relation']"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  
  <xsl:variable name="restrictions">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/fileDesc/publicationStmt/availability/licence/ab[@type='availability_txmweb']/@subtype">
        <xsl:value-of select="/TEI/teiHeader/fileDesc/publicationStmt/availability/licence/ab[@type='availability_txmweb']/@subtype"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="siecle">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/profileDesc/creation/date[@type='compo']/@n">
        <xsl:value-of select="/TEI/teiHeader/profileDesc/creation/date[@type='compo']/@n"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="ssiecle">
    <xsl:choose>
      <xsl:when test="ssiecle=/TEI/teiHeader/profileDesc/creation/date[@type='compo_sous_siecle']/@n">
        <xsl:value-of select="ssiecle=/TEI/teiHeader/profileDesc/creation/date[@type='compo_sous_siecle']/@n"/>
      </xsl:when>
      <xsl:otherwise>non spécifié</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="titre">
    <xsl:choose>
      <xsl:when test="/TEI/teiHeader/fileDesc/titleStmt/title[@type='main']">
        <xsl:value-of select="/TEI/teiHeader/fileDesc/titleStmt/title[@type='main'][1]"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="/TEI/teiHeader/fileDesc/titleStmt/title[1]"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  

<xsl:template match="text">
  <xsl:copy>
    <xsl:apply-templates select="@*"/>
    <xsl:attribute name="id"><xsl:value-of select="$current-file-name"/></xsl:attribute>
    <xsl:attribute name="auteur"><xsl:value-of select="$auteur"/></xsl:attribute>
    <xsl:attribute name="datecompolibre"><xsl:value-of select="$datecompolibre"/></xsl:attribute>
    <xsl:attribute name="datecompo"><xsl:value-of select="$datecompo"/></xsl:attribute>
    <xsl:attribute name="deaf"><xsl:value-of select="$deaf"/></xsl:attribute>
    <xsl:attribute name="dialecte"><xsl:value-of select="$dialecte"/></xsl:attribute>
    <xsl:attribute name="domaine"><xsl:value-of select="$domaine"/></xsl:attribute>
    <xsl:attribute name="edcomm"><xsl:value-of select="$edcomm"/></xsl:attribute>
    <xsl:attribute name="eddate"><xsl:value-of select="$eddate"/></xsl:attribute>
    <xsl:attribute name="ednum"><xsl:value-of select="$ednum"/></xsl:attribute>
    <xsl:attribute name="edsci"><xsl:value-of select="$edsci"/></xsl:attribute>
    <xsl:attribute name="edville"><xsl:value-of select="$edville"/></xsl:attribute>
    <xsl:attribute name="forme"><xsl:value-of select="$forme"/></xsl:attribute>
    <xsl:attribute name="genre"><xsl:value-of select="$genre"/></xsl:attribute>
    <xsl:attribute name="lemmatisation"><xsl:value-of select="$lemmatisation"/></xsl:attribute>
    <xsl:attribute name="morphosynt"><xsl:value-of select="$morphosynt"/></xsl:attribute>
    <xsl:attribute name="msdatelibre"><xsl:value-of select="$msdatelibre"/></xsl:attribute>
    <xsl:attribute name="msdate"><xsl:value-of select="$msdate"/></xsl:attribute>
    <xsl:attribute name="msnotafter"><xsl:value-of select="$msnotafter"/></xsl:attribute>
    <xsl:attribute name="msnotbefore"><xsl:value-of select="$msnotbefore"/></xsl:attribute>
    <xsl:attribute name="notafter"><xsl:value-of select="$notafter"/></xsl:attribute>
    <xsl:attribute name="notbefore"><xsl:value-of select="$notbefore"/></xsl:attribute>
    <xsl:attribute name="relation"><xsl:value-of select="$relation"/></xsl:attribute>
    <xsl:attribute name="restrictions"><xsl:value-of select="$restrictions"/></xsl:attribute>
    <xsl:attribute name="siecle"><xsl:value-of select="$siecle"/></xsl:attribute>
    <xsl:attribute name="ssiecle"><xsl:value-of select="$ssiecle"/></xsl:attribute>
    <xsl:attribute name="titre"><xsl:value-of select="$titre"/></xsl:attribute>
    <xsl:apply-templates/>
  </xsl:copy>
</xsl:template>


</xsl:stylesheet>