<?xml version="1.0"?>
<xsl:stylesheet xmlns:edate="http://exslt.org/dates-and-times"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tei="http://www.tei-c.org/ns/1.0"
  xmlns:txm="http://textometrie.org/1.0" xmlns:xs="http://www.w3.org/2001/XMLSchema"
  exclude-result-prefixes="tei edate txm xs" xpath-default-namespace="http://www.tei-c.org/1.0" version="2.0">

  <!--
This software is dual-licensed:

1. Distributed under a Creative Commons Attribution-ShareAlike 3.0
Unported License http://creativecommons.org/licenses/by-sa/3.0/ 

2. http://www.opensource.org/licenses/BSD-2-Clause
		
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

* Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

This software is provided by the copyright holders and contributors
"as is" and any express or implied warranties, including, but not
limited to, the implied warranties of merchantability and fitness for
a particular purpose are disclaimed. In no event shall the copyright
holder or contributors be liable for any direct, indirect, incidental,
special, exemplary, or consequential damages (including, but not
limited to, procurement of substitute goods or services; loss of use,
data, or profits; or business interruption) however caused and on any
theory of liability, whether in contract, strict liability, or tort
(including negligence or otherwise) arising in any way out of the use
of this software, even if advised of the possibility of such damage.

     
This stylesheet adds a ref attribute to w elements that will be used for
references in TXM concordances. Can be used with TXM XTZ import module.

Written by Alexei Lavrentiev, UMR 5317 IHRIM, 2017
  -->


  <xsl:output method="xml" encoding="utf-8" omit-xml-declaration="no"/> 
  
  
  <!-- General patterns: all elements, attributes, comments and processing instructions are copied -->
  
  <xsl:template match="*" mode="#all">      
        <xsl:copy>
          <xsl:apply-templates select="*|@*|processing-instruction()|comment()|text()" mode="#current"/>
        </xsl:copy>    
  </xsl:template>
  
  <xsl:template match="*" mode="position"><xsl:value-of select="count(preceding-sibling::*)"/></xsl:template>

  <xsl:template match="@*|comment()|processing-instruction()" mode="#all">
    <xsl:copy/>
  </xsl:template>
  
  <xsl:template match="/*:TEI">
    <xsl:copy>
      <xsl:namespace name="txm">http://textometrie.org/1.0</xsl:namespace>
      <xsl:apply-templates select="@*"/>
      <xsl:apply-templates/>
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="tei:w">
    <xsl:variable name="pN" as="xs:integer">
      <xsl:choose>
        <xsl:when test="string(number(ancestor::tei:p[1]/@n))='NaN'">0</xsl:when>
        <xsl:otherwise><xsl:value-of select="ancestor::tei:p[1]/@n"/></xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="wN">
      <xsl:number level="any"/>
    </xsl:variable>
    <!--<xsl:variable name="pN">
      
        <xsl:value-of select="ancestor::tei:p[1]/@n"/>
      
    </xsl:variable>-->
    <xsl:variable name="ref">
      <xsl:if test="ancestor::tei:text/@*:id"></xsl:if>
      <xsl:value-of select="ancestor::tei:text[1]/@*:id[1]"/>
      <xsl:if test="ancestor::tei:text/@*:id and (preceding::tei:pb[1]/@n or preceding::tei:cb[1]/@n)">
        <xsl:text>, </xsl:text>
      </xsl:if>
      <xsl:if test="preceding::tei:pb[1]/@n and not(matches(preceding::tei:cb[1]/@n,'^\d'))">
        <xsl:text>p. </xsl:text>
        <xsl:value-of select="preceding::tei:pb[1]/@n"/>
      </xsl:if>
      <xsl:if test="preceding::tei:pb[1]/@n and preceding::tei:cb[1]/@n and not(matches(preceding::tei:cb[1]/@n,'^\d'))">
        <xsl:text>, </xsl:text>
      </xsl:if>
<!--      <xsl:if test="preceding::tei:cb[1]/@n">-->
        <xsl:text>col. </xsl:text>
        <xsl:value-of select="preceding::tei:cb[@n][1]/substring-after(@xml:id,'col_')"/>
      <!--</xsl:if>-->
      <xsl:if test="(ancestor::tei:text/@*:id or preceding::tei:pb[1]/@n or preceding::tei:cb[1]/@n) and preceding::tei:lb[1]/@n">
        <xsl:text>, </xsl:text>
      </xsl:if>
      <xsl:if test="preceding::tei:lb[1]/@n">
        <xsl:text>l. </xsl:text>
        <xsl:value-of select="preceding::tei:lb[1]/@n"/>
      </xsl:if>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="matches(.,'^\s*$')">
        <xsl:apply-templates/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy>
          <xsl:apply-templates select="@*"/>
          <xsl:attribute name="ref"><xsl:value-of select="$ref"/></xsl:attribute>
          <xsl:attribute name="aggl">
            <xsl:choose>
              <xsl:when test="matches(@rend,'fgmt')">fgmt</xsl:when>
              <xsl:when test="matches(@rend,'aggl')">aggl</xsl:when>
              <xsl:when test="matches(.,'''$')">elision</xsl:when>
              <xsl:otherwise>no</xsl:otherwise>
            </xsl:choose>
          </xsl:attribute>
          <xsl:attribute name="dipl"><xsl:apply-templates select="*|text()" mode="dipl"/></xsl:attribute>
          <xsl:attribute name="pn"><xsl:value-of select="$pN"/></xsl:attribute>
          <xsl:attribute name="facs">
            <!--<xsl:apply-templates select="*|text()" mode="facs"/>-->
            <xsl:choose>
              <xsl:when test="$pN lt 13"><xsl:apply-templates select="*|text()" mode="facs"/></xsl:when>
              <xsl:otherwise>__UNDEF__</xsl:otherwise>
            </xsl:choose>
          </xsl:attribute>
          <xsl:attribute name="oldid"><xsl:value-of select="@xml:id"/></xsl:attribute>
          <xsl:attribute name="xml:id"><xsl:value-of select="concat('w_qgraal_cm_',$wN)"/></xsl:attribute>
          <xsl:apply-templates select="*|processing-instruction()|comment()|text()" mode="norm"/>
          <!-- provoque txm:form imbriqués -->
          <!--<txm:form xmlns="http://textometrie.org/1.0"><xsl:apply-templates select="*|processing-instruction()|comment()|text()" mode="norm"/></txm:form>
          <txm:ana xmlns="http://textometrie.org/1.0" resp="#txm" type="#dipl"><xsl:apply-templates select="*|processing-instruction()|comment()|text()" mode="dipl"/></txm:ana>-->
          <xsl:if test="@rend='elision' and not(matches(.,'[''’]\s*$'))">
            <xsl:text>'</xsl:text>
          </xsl:if>
        </xsl:copy>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>  
  
  <!-- les anciens w@id sont transférés vers @oldid -->
  <xsl:template match="tei:w/@xml:id"/>
  
  <!-- les w/@type devient @pos -->
  <xsl:template match="tei:w/@type">
    <xsl:attribute name="pos"><xsl:value-of select="."/></xsl:attribute>
  </xsl:template>
 
  <!--<xsl:template match="*:ex" mode="norm" xml:space="default"><xsl:apply-templates/></xsl:template>-->
  
  <xsl:template match="tei:choice" mode="norm">
    <xsl:apply-templates select="tei:corr|tei:reg|tei:expan" mode="#current"/>
  </xsl:template>
  
  <xsl:template match="tei:choice" mode="dipl">
    <xsl:apply-templates select="tei:sic|tei:orig|tei:expan" mode="#current"/>
  </xsl:template>
  
  <xsl:template match="tei:choice" mode="facs">
    <xsl:apply-templates select="tei:sic|tei:orig|tei:abbr" mode="#current"/>
  </xsl:template>
  
  <xsl:template match="tei:lb" mode="dipl facs">||</xsl:template>
  
  <xsl:template match="tei:lb" mode="norm">
    <xsl:copy>
      <xsl:apply-templates select="@*"/>
      <xsl:if test="preceding-sibling::*[1][self::tei:c[@type='hyphen']]">
        <xsl:attribute name="rend">
          <xsl:text>hyphen(</xsl:text>
          <xsl:value-of select="preceding-sibling::tei:c[1]"/>
          <xsl:text>)</xsl:text>
        </xsl:attribute>
      </xsl:if>
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="tei:pb" mode="#all">
    <milestone xmlns="http://www.tei-c.org/ns/1.0" unit="ms-page">
      <xsl:apply-templates select="@*"/>
      <xsl:attribute name="facs"><xsl:value-of select="concat('http://txm.ish-lyon.cnrs.fr/txm/images/img/',@facs)"/></xsl:attribute>
<!--      <xsl:attribute name="facs"><xsl:value-of select="concat('/home/alavrent/Documents/Mes documents/Queste/Images_small_fol/',@facs)"/></xsl:attribute>-->
    </milestone>
    
  </xsl:template>
  
  <xsl:template match="tei:cb" mode="#all">
    <xsl:choose>
      <xsl:when test="@rend='printonly'">
        <milestone xmlns="http://www.tei-c.org/ns/1.0" unit="cb-printonly">
          <xsl:apply-templates select="@*"/>  
        </milestone>
      </xsl:when>
      <xsl:otherwise>
        <pb xmlns="http://www.tei-c.org/ns/1.0">
          <xsl:apply-templates select="@*"/>
          <xsl:attribute name="facs"><xsl:value-of select="concat('http://txm.ish-lyon.cnrs.fr/txm/images/img/',@facs)"/></xsl:attribute>
          <!--<xsl:attribute name="facs"><xsl:value-of select="concat('/home/alavrent/Documents/Mes documents/Queste/Images_small_col/',@facs)"/></xsl:attribute>-->
        </pb>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  
  <xsl:template match="tei:ex" mode="dipl">‹<xsl:apply-templates mode="#current"/>›</xsl:template>
  
  <xsl:template match="tei:c[@type='hyphen']" mode="norm"/>
  
  <xsl:template match="tei:g[@type='initiale']" mode="norm">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()"/>
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="tei:g[@type='initiale']" mode="dipl facs">
    <xsl:text>{</xsl:text>
    <xsl:apply-templates mode="#current"/>
    <xsl:text>}</xsl:text>
  </xsl:template>
  
  <xsl:template match="tei:note">
    <xsl:copy>
      <xsl:apply-templates select="@*"/>
      <xsl:if test="not(@*:id)">
        <xsl:attribute name="xml:id">
          <xsl:value-of select="generate-id()"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:attribute name="fromPage">
        <xsl:value-of select="concat('#',preceding::tei:cb[1]/@*:id[1])"/>
      </xsl:attribute>
      <xsl:apply-templates/>
    </xsl:copy>
  </xsl:template>
    
  <xsl:template match="text()" mode="norm">
    <xsl:analyze-string select="normalize-space(.)" regex="\+\+?_?\??">
      <xsl:matching-substring></xsl:matching-substring>
      <xsl:non-matching-substring><xsl:call-template name="diacritics-norm"/></xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>
  
  <xsl:template match="text()" mode="dipl">
    <xsl:analyze-string select="normalize-space(.)" regex="\+\+?_?\??$|'$">
      <xsl:matching-substring></xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:call-template name="diacritics-dipl"/>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>
  
  <xsl:template match="text()" mode="facs">
    <xsl:analyze-string select="normalize-space(.)" regex="\+\+?_?\??$|'$">
      <xsl:matching-substring></xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:call-template name="diacritics-facs"/>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>
  
  
  <xsl:template name="diacritics-norm">
    <xsl:call-template name="ramiste-norm">
      <xsl:with-param name="string">
        <xsl:value-of select="translate(.,'íſᷤᷥẏꝛ','isssyr')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template name="diacritics-dipl">
    <xsl:call-template name="ramiste-dipl">
      <xsl:with-param name="string">
        <xsl:value-of select="translate(.,'éëïíüÇçſᷥᷤẏꝛ','eeiiuCcsssyr')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  
  <xsl:template name="diacritics-facs">
    <xsl:call-template name="ramiste-dipl">
      <xsl:with-param name="string">
        <xsl:value-of select="translate(.,'éëïüÇç','eeiuCc')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template name="ramiste-norm">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:analyze-string select="$string" regex="#?#?(\*?\*?)([IJUVijuv])">
      <xsl:matching-substring>
        <xsl:variable name="star"><xsl:value-of select="regex-group(1)"/></xsl:variable>
        <xsl:variable name="letter"><xsl:value-of select="regex-group(2)"/></xsl:variable>
        <xsl:call-template name="capitals-norm">
          <xsl:with-param name="string">
            <xsl:choose>
              <xsl:when test="matches($star,'\*\*')">
                <xsl:value-of select="translate($letter,'IJUVijuv','JIVUjivu')"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="$letter"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:call-template name="capitals-norm"/>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>
  
  <xsl:template name="ramiste-dipl">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:analyze-string select="$string" regex="#?(\*?\*?)([IJUVijuv])">
      <xsl:matching-substring>
        <xsl:variable name="star"><xsl:value-of select="regex-group(1)"/></xsl:variable>
        <xsl:variable name="letter"><xsl:value-of select="regex-group(2)"/></xsl:variable>
        <xsl:call-template name="capitals-dipl">
          <xsl:with-param name="string">
            <xsl:choose>
              <xsl:when test="matches($star,'\*\*')">
                <xsl:value-of select="$letter"/>
              </xsl:when>
              <xsl:when test="matches($star,'\*')">
                <xsl:value-of select="translate($letter,'IJUVijuv','JJVVjjvv')"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="translate($letter,'IJUVijuv','IIUUiiuu')"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:call-template name="capitals-dipl"/>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>
  
  <xsl:template name="ramiste-facs">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:analyze-string select="$string" regex="#?(\*?\*?)([IJUVijuví])">
      <xsl:matching-substring>
        <xsl:variable name="star"><xsl:value-of select="regex-group(1)"/></xsl:variable>
        <xsl:variable name="letter"><xsl:value-of select="regex-group(2)"/></xsl:variable>
        <xsl:call-template name="capitals-facs">
          <xsl:with-param name="string">
            <xsl:choose>
              <xsl:when test="matches($star,'\*\*')">
                <xsl:value-of select="regex-group(1)"/>
              </xsl:when>
              <xsl:when test="matches($star,'\*')">
                <xsl:value-of select="translate($letter,'IJUVijuv','JJVVjjvv')"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="translate($letter,'IJUVijuv','IIUUiiuu')"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:call-template name="capitals-facs"/>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>

<xsl:template name="capitals-norm">
  <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
  <xsl:analyze-string select="$string" regex="#?#([A-Za-zéçïü])">
    <xsl:matching-substring>
      <xsl:choose>
        <xsl:when test="matches(.,'##') and matches(regex-group(1),'[A-Z]')">
          <xsl:value-of select="lower-case(regex-group(1))"/>
        </xsl:when>
        <xsl:when test="matches(.,'##') and matches(regex-group(1),'[a-zéçïü]')">
          <xsl:value-of select="upper-case(regex-group(1))"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="regex-group(1)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:matching-substring>
    <xsl:non-matching-substring>
      <xsl:call-template name="ponct-norm"/>
    </xsl:non-matching-substring>
  </xsl:analyze-string>
</xsl:template>
  
  <xsl:template name="capitals-dipl">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:analyze-string select="$string" regex="#?#([A-Za-zéçïü])">
      <xsl:matching-substring>
        <xsl:choose>
          <xsl:when test="matches(.,'##')">
            <xsl:value-of select="translate(.,'#','')"/>
          </xsl:when>
          <xsl:when test="matches(regex-group(1),'[A-Z]')">
            <xsl:value-of select="lower-case(regex-group(1))"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="upper-case(regex-group(1))"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:call-template name="ponct-dipl"/>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>
  
  <xsl:template name="capitals-facs">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:analyze-string select="$string" regex="#?#(.)">
      <xsl:matching-substring>
        <xsl:choose>
          <xsl:when test="matches(.,'##')"><xsl:value-of select="regex-group(1)"/></xsl:when>
          <xsl:when test="matches(regex-group(1),'[A-Z]')">
            <xsl:value-of select="lower-case(regex-group(1))"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="upper-case(regex-group(1))"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:call-template name="ponct-facs"/>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>
  
  
  
  <xsl:template name="ponct-norm">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:analyze-string select="$string" regex="^((.*)%.*%.*|([.,]))$">
      <xsl:matching-substring>
        <xsl:choose>
          <xsl:when test="matches(regex-group(2),'\S')">
            <xsl:value-of select="regex-group(2)"></xsl:value-of>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="regex-group(3)"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:call-template name="deglutinations-norm"></xsl:call-template>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>
  
  <xsl:template name="ponct-dipl">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:analyze-string select="$string" regex="^(.*%(.*)%.*|([.,]))$">
      <xsl:matching-substring>
        <xsl:choose>
          <xsl:when test="matches(regex-group(2),'\S')">
            <xsl:value-of select="regex-group(2)"/>
          </xsl:when>
          <xsl:when test="matches(regex-group(3),'\S')">
            <!-- ponctuation diplomatique "par défaut" -->
            <xsl:text>.</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <!-- pas de ponctuation diplomatique-->
          </xsl:otherwise>
        </xsl:choose>
      </xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:call-template name="deglutinations-dipl"></xsl:call-template>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>
  
  <xsl:template name="ponct-facs">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:analyze-string select="$string" regex="^(.*%.*%(.*)|([.,]))$">
      <xsl:matching-substring>
        <xsl:choose>
          <xsl:when test="matches(regex-group(2),'\S')">
            <xsl:value-of select="regex-group(2)"/>
          </xsl:when>
          <xsl:when test="matches(regex-group(3),'\S')">
            <!-- ponctuation diplomatique "par défaut" -->
            <xsl:text>.</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <!-- pas de ponctuation diplomatique-->
          </xsl:otherwise>
        </xsl:choose>
      </xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:call-template name="deglutinations-dipl"></xsl:call-template>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>
  
  <xsl:template name="deglutinations-norm">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:analyze-string select="$string" regex="__?\??">
      <xsl:matching-substring>
        <space xmlns="http://www.tei-c.org/ns/1.0">
          <xsl:attribute name="type">
            <xsl:choose>
              <xsl:when test="matches(.,'__')">degl-fgmt</xsl:when>
              <xsl:otherwise>degl</xsl:otherwise>
            </xsl:choose>
          </xsl:attribute>
          <xsl:if test="matches(.,'\?')">
            <xsl:attribute name="cert">no</xsl:attribute>
          </xsl:if>
        </space>
      </xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:value-of select="."/>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>
  
  <xsl:template name="deglutinations-dipl">
    <xsl:param name="string"><xsl:value-of select="."/></xsl:param>
    <xsl:analyze-string select="$string" regex="__?\??">
      <xsl:matching-substring>
          <xsl:value-of select="."/>
      </xsl:matching-substring>
      <xsl:non-matching-substring>
        <xsl:value-of select="."/>
      </xsl:non-matching-substring>
    </xsl:analyze-string>
  </xsl:template>
  

</xsl:stylesheet>