<?xml version="1.0"?>
<xsl:stylesheet xmlns:edate="http://exslt.org/dates-and-times"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:tei="http://www.tei-c.org/ns/1.0" 
	xmlns:txm="http://textometrie.org/1.0"
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
                exclude-result-prefixes="#all" version="2.0">
                
	<xsl:output method="xml" encoding="UTF-8" omit-xml-declaration="no" indent="no"/>
	
	<!-- <xsl:output method="xml" encoding="UTF-8" omit-xml-declaration="no" indent="no"  doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/> -->
	
                
                <xsl:strip-space elements="*"/>
                
	<xsl:param name="pagination-element">cb</xsl:param>
	
	<!-- Set "colonne" to use column numbers as TXM page identifiers. Any other value will use standard page count -->
	<xsl:param name="page-numbering"/>
	
	
	<xsl:variable name="word-element">
		<xsl:choose>
			<xsl:when test="//tei:c//txm:form">c</xsl:when>
			<xsl:otherwise>w</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="page-number-adjust" as="xs:integer">
		<xsl:choose>
			<xsl:when test="//tei:c//txm:form">1</xsl:when>
			<xsl:otherwise>2</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	

                <xsl:variable name="inputtype">
                	<xsl:choose>
                		<xsl:when test="//tei:w//txm:form">xmltxm</xsl:when>
                		<xsl:otherwise>xmlw</xsl:otherwise>
                	</xsl:choose>
                </xsl:variable>
	
	<xsl:variable name="filename">
		<xsl:analyze-string select="document-uri(.)" regex="^(.*)/([^/]+)\.[^/]+$">
			<xsl:matching-substring>
				<xsl:value-of select="regex-group(2)"/>
			</xsl:matching-substring>
		</xsl:analyze-string>
	</xsl:variable>
                
                <xsl:template match="/">
                	<html>
                		<head>
                			<title><xsl:choose>
                				<xsl:when test="//tei:text/@id"><xsl:value-of select="//tei:text[1]/@id"/></xsl:when>
                				<xsl:otherwise><xsl:value-of select="$filename"/></xsl:otherwise>
                			</xsl:choose></title>
                			<meta http-equiv="Content-Type" content="text/html;charset=UTF-8"/>
                			<!--<link rel="stylesheet" media="all" type="text/css" href="css/bvhepistemon2014.css" />-->
<!--                			<title>
                				<xsl:if test="$author[not(contains(.,'anonym'))]">
                					<xsl:value-of select="$author"/><xsl:text> : </xsl:text>
                				</xsl:if>
                				<xsl:value-of select="$title-normal"/>
                			</title>                                                                -->
                		</head>
                			<xsl:apply-templates select="descendant::tei:text"/>
                	</html>
                </xsl:template>

<xsl:template match="tei:text">
	<body>
		<xsl:if test="$word-element='w'">
			<a class="txm-page" title="1"  next-word-id="w_0"/>
			<div class="metadata-page">
				<!--<img src="http://bfm.ens-lyon.fr/local/cache-vignettes/L166xH100/siteon0-bb432.png" style="position:absolute;left:-10px;top:-5px;height:50px;width:83px" alt="BFM"/>-->
				<xsl:if test="@auteur and not(matches(@auteur,'nonym'))">
					<h2><xsl:value-of select="@auteur"/></h2>
				</xsl:if>
				<h1><xsl:choose>
					<xsl:when test="@titre"><xsl:value-of select="@titre"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="@id"/></xsl:otherwise>
				</xsl:choose></h1>
				<xsl:if test="@datecompolibre">
					<h3>
						<xsl:text>(</xsl:text>
						<xsl:value-of select="normalize-space(@datecompolibre)"/>
						<xsl:text>)</xsl:text>
					</h3>
				</xsl:if>
				<h3>Transcription normalisée</h3>
				<xsl:if test="ancestor::tei:TEI/tei:teiHeader//tei:ab[@type='how_to_cite']">
					<p><i>Pour citer ce texte :</i> <br/>
						<xsl:value-of select="ancestor::tei:TEI/tei:teiHeader//tei:ab[@type='how_to_cite']/tei:bibl"/></p>
				</xsl:if>
				
				<br/>
				<h2>Métadonnées :</h2>
				<table>
					<xsl:for-each select="@*[not(matches(name(),'textorder'))]">
						<xsl:sort select="name()"/>
						<tr>
							<td><xsl:value-of select="name()"/></td>
							<td><xsl:value-of select="."/></td>
						</tr>
					</xsl:for-each>
				</table>
			</div>
			
			
		</xsl:if>
		<xsl:apply-templates/>
		<!--<xsl:variable name="page_id"><xsl:value-of select="count(descendant::*[local-name()=$pagination-element])"/></xsl:variable>-->
		
		<xsl:variable name="previousPageId"><xsl:text>pb_</xsl:text><xsl:value-of select="count(descendant::*[local-name()=$pagination-element])"/></xsl:variable>
		
		
		<xsl:call-template name="footnotes">
			<xsl:with-param name="previousPageId"><xsl:value-of select="$previousPageId"/></xsl:with-param>
		</xsl:call-template>
		

	</body>
</xsl:template>

                <xsl:template match="*">
                                <xsl:choose>
                                	<xsl:when test="descendant::tei:p[not(ancestor::tei:note)]|descendant::tei:ab[not(ancestor::tei:note)]">
                                		<div>
                                			<xsl:call-template name="addClass"/>
                                			<xsl:apply-templates/></div>
                                		<xsl:text>&#xa;</xsl:text>
                                	</xsl:when>
                                	<xsl:otherwise><span>
                                		<xsl:call-template name="addClass"/>
                                		<xsl:if test="self::tei:add[@del]">
                                			<xsl:attribute name="title"><xsl:value-of select="@del"/></xsl:attribute>
                                		</xsl:if>
                                		<xsl:apply-templates/></span>
                                	<xsl:call-template name="spacing"/>
                                	</xsl:otherwise>
                                </xsl:choose>
                </xsl:template>
                
                <xsl:template match="@*|processing-instruction()|comment()">
                                <!--<xsl:copy/>-->
                </xsl:template>
                
<!--                <xsl:template match="comment()">
                                <xsl:copy/>
                </xsl:template>
-->                
                <xsl:template match="text()">
                                <xsl:value-of select="normalize-space(translate(.,'''','’'))"/>
                </xsl:template>
                
                <xsl:template name="addClass">
                	<xsl:attribute name="class">
                		<xsl:value-of select="local-name(.)"/>
                		<xsl:if test="@type"><xsl:value-of select="concat('-',@type)"/></xsl:if>
                		<xsl:if test="@subtype"><xsl:value-of select="concat('-',@subtype)"/></xsl:if>
                		<xsl:if test="@rend"><xsl:value-of select="concat('-',@rend)"/></xsl:if>
                	</xsl:attribute>                	
                </xsl:template>
                
                <xsl:template match="tei:p[not(ancestor::tei:note)]|tei:lg">
                	<p>
                		<xsl:call-template name="addClass"/>
                		<xsl:if test="@n">
                			<span class="verselinenumber"><span class="numbering">
                				<xsl:value-of select="concat('§ ',@n)"/>
                			</span></span>
                			<br/>
                		</xsl:if>
                		<xsl:apply-templates/>
                	</p>
                	<xsl:text>&#xa;</xsl:text>
                </xsl:template>

	<xsl:template match="tei:note//tei:p">
		<xsl:apply-templates/>
		<br/>
		<xsl:text>&#xa;</xsl:text>
	</xsl:template>
	
	<xsl:template match="tei:note//tei:hi[@rend='italic']">
		<span class="hi-italic">
			<xsl:text> </xsl:text>
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="tei:ab">
		<span>
			<xsl:call-template name="addClass"/>
			<xsl:if test="@n and not(*[1][self::tei:lb])">
				<span class="ab_number">
					<xsl:text>&lt;§ </xsl:text>
					<xsl:value-of select="@n"/>
					<xsl:text>> </xsl:text>
				</span>
			</xsl:if>
			<xsl:apply-templates/>
		</span>
		<xsl:text>&#xa;</xsl:text>
	</xsl:template>
	
		
	<xsl:template match="tei:head">
		<xsl:choose>
			<xsl:when test="parent::tei:div/parent::tei:body">
				<h2>
					<xsl:call-template name="addClass"/>
					<xsl:if test="matches(@xml:lang,'^fra?$')">
						<xsl:text>[</xsl:text>
					</xsl:if>
					<xsl:apply-templates/>
					<xsl:if test="matches(@xml:lang,'^fra?$')">
						<xsl:text>]</xsl:text>
					</xsl:if>
				</h2>		
			</xsl:when>
			<xsl:otherwise/>
		</xsl:choose>
		
	</xsl:template>
	
	<xsl:template match="tei:milestone[@unit='page' and @ed='Pauphilet1923']">
		<span class="numbering">
			<xsl:value-of select="concat('(p. ',@n,')')"/>
		</span>
		<xsl:call-template name="spacing"/>
	</xsl:template>
                
	<xsl:template match="tei:lb[not(ancestor::tei:note[@type='sic'])]">
		<xsl:variable name="lbcount">
			<xsl:choose>
				<xsl:when test="ancestor::tei:ab"><xsl:number from="tei:ab" level="any"/></xsl:when>
				<xsl:when test="ancestor::tei:p"><xsl:number from="tei:p" level="any"/></xsl:when>
				<xsl:otherwise>999</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
<!--		<xsl:if test="@rend='hyphen(-)'"><span class="hyphen">-</span></xsl:if>
		<xsl:if test="@rend='hyphen(=)'"><span class="hyphen">=</span></xsl:if>-->
		<xsl:if test="ancestor::tei:w and not(ancestor::tei:w//tei:pb or ancestor::tei:w//tei:cb)"><span class="hyphen">-</span></xsl:if>
		<xsl:if test="not($lbcount=1) or preceding-sibling::node()[matches(.,'\S')]"><br/><xsl:text>&#xa;</xsl:text></xsl:if>
<!--		<xsl:if test="@n and not(@rend='prose')">
			<xsl:choose>
				<xsl:when test="matches(@n,'^[0-9]*[05]$')">
					<!-\-<a title="{@n}" class="verseline" style="position:relative"> </a>-\->
					<span class="verseline"><span class="verselinenumber"><xsl:value-of select="@n"/></span></span>
				</xsl:when>
				<xsl:when test="matches(@n,'[^0-9]')">
					<!-\-<a title="{@n}" class="verseline" style="position:relative"> </a>-\->
					<span class="verseline"><span class="verselinenumber"><xsl:value-of select="@n"/></span></span>
				</xsl:when>
				<xsl:otherwise>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>-->
		<xsl:if test="matches(@n,'[05]\]?$')">
			<!--<span class="verseline"><span class="verselinenumber"><xsl:value-of select="@n"/></span></span>-->
			<span class="verselinenumber"><xsl:value-of select="@n"/></span>
		</xsl:if>
		<xsl:if test="parent::tei:ab[@n] and not(preceding-sibling::*)">
			<span class="ab_number">
				<xsl:text>&lt;§ </xsl:text>
				<xsl:value-of select="parent::tei:ab/@n"/>
				<xsl:text>> </xsl:text>
			</span>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="tei:lb[ancestor::tei:note[@type='sic']]">
		<xsl:text>||</xsl:text>
	</xsl:template>
	
	<xsl:template match="tei:cb">
		<xsl:if test="ancestor::tei:w and not(preceding-sibling::*[1][self::tei:pb])"><span class="hyphen">-</span></xsl:if>
		<span class="editionpage">
			<xsl:text>&lt;colonne </xsl:text>
			<xsl:value-of select="replace(@n,'^.*([abcd]).*$','$1')"/>
			<xsl:text>&gt;</xsl:text>
		</span>
	</xsl:template>
	
	<!-- Page breaks -->                
	<xsl:template match="*[local-name()=$pagination-element]">
		
		<xsl:variable name="next-word-position" as="xs:integer">
			<xsl:choose>
				<xsl:when test="following::*[local-name()=$word-element]">
					<xsl:value-of select="count(following::*[local-name()=$word-element][1]/preceding::*[local-name()=$word-element])"/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="next-pb-position" as="xs:integer">
			<xsl:choose>
				<xsl:when test="following::*[local-name()=$pagination-element]">
					<xsl:value-of select="count(following::*[local-name()=$pagination-element][1]/preceding::*[local-name()=$word-element])"/>
				</xsl:when>
				<xsl:otherwise>999999999</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="next-word-id">
			<xsl:choose>
				<xsl:when test="$next-pb-position - $next-word-position = 999999999">w_0</xsl:when>
				<xsl:when test="$next-pb-position &gt; $next-word-position"><xsl:value-of select="following::*[local-name()=$word-element][1]/@id"/></xsl:when>
				<xsl:otherwise>w_0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		
		<xsl:variable name="editionpagetype">
			<xsl:choose>
				<xsl:when test="ancestor::tei:ab">editionpageverse</xsl:when>
				<xsl:otherwise>editionpage</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="pagenumber">
			<!--<xsl:choose>
				<xsl:when test="@n"><xsl:value-of select="@n"/></xsl:when>
				<xsl:when test="@facs"><xsl:value-of select="substring-before(@facs,'.')"/></xsl:when>
				<xsl:otherwise>[NN]</xsl:otherwise>
			</xsl:choose>-->
			<xsl:analyze-string select="@facs" regex="lyonbm_pa77-(z?_?\d+[abcd])">
				<xsl:matching-substring><xsl:value-of select="regex-group(1)"/></xsl:matching-substring>
			</xsl:analyze-string>
		</xsl:variable>
		
		<!--<xsl:variable name="page_id"><xsl:value-of select="count(preceding::*[local-name()=$pagination-element])"/></xsl:variable>-->
		<xsl:variable name="previousPageId"><xsl:value-of select="preceding::*[local-name()=$pagination-element][1]/@*:id[1]"/></xsl:variable>
		
		<!--<xsl:if test="following-sibling::*[1][self::tei:lb[@break='no']]"><span class="hyphen">-</span></xsl:if>-->
		<xsl:if test="ancestor::tei:w"><span class="hyphen">-</span></xsl:if>
		
		<xsl:call-template name="footnotes">
			<xsl:with-param name="previousPageId"><xsl:value-of select="$previousPageId"/></xsl:with-param>
		</xsl:call-template>
		
		
		<xsl:text>&#xa;</xsl:text>
		<br/><xsl:text>&#xa;</xsl:text>
		
		<xsl:choose>
			<xsl:when test="$page-numbering='colonne'"><a class="txm-page" title="{substring-after(@xml:id,'col_')}" next-word-id="{$next-word-id}"/></xsl:when>
			<xsl:otherwise><a class="txm-page" title="{count(preceding::*[local-name()=$pagination-element]) + $page-number-adjust}" next-word-id="{$next-word-id}"/></xsl:otherwise>
		</xsl:choose>
		
		<span class="{$editionpagetype}"> &lt;<xsl:value-of select="$pagenumber"/>&gt; </span><!--<br/>--><xsl:text>&#xa;</xsl:text>
	
	<!--<xsl:variable name="n" as="xs:integer">
		<xsl:value-of select="@n"/>
	</xsl:variable>-->
		
		<xsl:variable name="n">
			<xsl:value-of select="@n"/>
		</xsl:variable>
		
	
		<span class="runningtitle">
			<xsl:choose>
				<xsl:when test="@n='1'"/>
				<xsl:when test="following::tei:div[@type='épisode'][1]/preceding::tei:pb[1][@n=$n]">
<!--					<xsl:text>1. </xsl:text>-->
					<xsl:value-of select="following::tei:div[@type='épisode'][1]/tei:head"/>
				</xsl:when>
				<xsl:when test="ancestor::tei:div[@type='épisode']">
					<!--<xsl:text>2. (</xsl:text>
					<xsl:value-of select="@n"/>
					<xsl:text> - </xsl:text>
					<xsl:value-of select="following::tei:div[@type='épisode'][1]/preceding::tei:pb[1]/@n"/>
					<xsl:text>) </xsl:text>-->
					<xsl:value-of select="ancestor::tei:div[@type='épisode']/tei:head"/>
				</xsl:when>
				<xsl:otherwise>
					<!--<xsl:text>3. </xsl:text>-->
					<xsl:value-of select="preceding::tei:div[@type='épisode'][1]/tei:head"/>
				</xsl:otherwise>
			</xsl:choose>
		</span><br/><xsl:text>&#xa;</xsl:text>
		

	</xsl:template>
	
	<xsl:template match="tei:note">
		<!--<span style="color:violet"> [<b>Note :</b> <xsl:apply-templates/>] </span>-->
		<xsl:choose>
			<xsl:when test="@place='inline'">
				<span class="noteinline">
					<xsl:text>(</xsl:text>
					<xsl:apply-templates/>
					<xsl:text>)</xsl:text>
				</span>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="note_count"><xsl:value-of select="count(preceding::tei:note[not(matches(@place,'inline'))]) + 1"/></xsl:variable>
				<xsl:variable name="note_content">
					<xsl:choose>
						<xsl:when test="descendant::txm:form">
							<xsl:for-each select="descendant::txm:form">						
								<xsl:value-of select="."/>
								<xsl:if test="not(matches(following::txm:form[1],'^[.,\)]')) and not(matches(.,'^\S+[''’]$|^[‘\(]$'))">
									<xsl:text> </xsl:text>
								</xsl:if>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise><xsl:value-of select="normalize-space(.)"/></xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<a title="{$note_content}" class="noteref" href="#{@*:id}" name="ref_{@*:id}">[<xsl:number count="tei:note[not(matches(@place,'inline'))]" level="any"/>]</a>
				<xsl:call-template name="spacing"/> 
				<xsl:if test="@type='sic' and descendant::tei:lb">
					<xsl:if test="matches(following-sibling::tei:w[1]/txm:form,'^[.,:;!?]+$')">
						<xsl:apply-templates select="following-sibling::tei:w[1]">
							<xsl:with-param name="movepunct">yes</xsl:with-param>
						</xsl:apply-templates>
					</xsl:if>
					<br/>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="footnotes">
		<xsl:param name="previousPageId"></xsl:param>
		
		<xsl:if test="//tei:note[@fromPage=concat('#',$previousPageId) and not(matches(@place,'inline'))]">
			<!-- [@fromPage='{concat(''#'',$previousPageId)}'] -->
			<xsl:text>&#xa;</xsl:text>
			<br/>
			<br/>			
			<span class="footnotes">
					<xsl:for-each select="//tei:note[not(matches(@place,'inline')) and @fromPage=concat('#',$previousPageId)]">
						<xsl:variable name="note_count"><xsl:value-of select="count(preceding::tei:note[not(matches(@place,'inline'))]) + 1"/></xsl:variable>
						<!--<p><xsl:value-of select="$note_count"/>. <a href="#noteref_{$note_count}" name="note_{$note_count}">[<xsl:value-of select="preceding::tei:cb[1]/@xml:id"/>, l. <xsl:value-of select="preceding::tei:lb[1]/@n"/>]</a><xsl:text> </xsl:text> <xsl:value-of select="."/></p>-->
						<span class="footnote">
							<span class="footnoteref">
								<a href="#ref_{@*:id}" name="{@*:id}">
									<xsl:value-of select="$note_count"/>
								</a>
							</span>
							<xsl:apply-templates mode="#current"/>
						</span>
					</xsl:for-each>
			</span><xsl:text>&#xa;</xsl:text>                                                                
			
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template match="tei:figure">
		<p>
			<img src="{tei:graphic/@url}" alt="{tei:figDesc/text()}"/>
		</p>
	</xsl:template>
	
	<xsl:template match="tei:bibl">
		<span class="noteref" title="{normalize-space(.)}">[•]</span>
	</xsl:template>
	
	<xsl:template match="a[@class='txmpageref']">
		<xsl:copy-of select="."/>
	</xsl:template>
	
	<!--<xsl:template match="tei:note[@place='inline']">
		<span class="noteinline">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
   -->             
                <xsl:template match="tei:w">
                	<xsl:param name="movepunct">no</xsl:param>
                	<span>
                	<xsl:attribute name="class">
                		<xsl:choose>
                			<!--<xsl:when test="matches(txm:ana[@type='#aggl'],'aggl')">w-aggl</xsl:when>-->
                			<xsl:when test="matches(txm:ana[@type='#aggl'],'fgmt')">w-fgmt</xsl:when>
                			<xsl:otherwise>w</xsl:otherwise>
                		</xsl:choose>
                	</xsl:attribute>
                	<xsl:choose>
                		<xsl:when test="descendant::tei:c//txm:form">
                			<xsl:apply-templates select="descendant::tei:c"/>
                		</xsl:when>
                		<xsl:when test="matches(txm:form,'^[.,:;!?]+$') and preceding-sibling::*[1][self::tei:note[descendant::tei:lb]] and $movepunct='no'"></xsl:when>
                		<xsl:otherwise>
                			<xsl:if test="@id">
                				<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
                			</xsl:if>
                			<xsl:attribute name="title">
                				<xsl:if test="@id">
                					<xsl:value-of select="@id"></xsl:value-of>
                				</xsl:if>
                				<xsl:if test="ancestor::tei:corr">
                					<xsl:value-of select="concat(' sic : ',@sic)"/>
                				</xsl:if>
                				<xsl:if test="ancestor::tei:reg">
                					<xsl:value-of select="concat(' orig : ',@orig)"/>
                				</xsl:if>
                				<xsl:choose>
                					<xsl:when test="descendant::txm:ana">	
                						<xsl:for-each select="descendant::txm:ana">
                							<xsl:value-of select="concat(' ',substring-after(@type,'#'),' : ',.)"/>
                						</xsl:for-each>
                					</xsl:when>
                					<xsl:otherwise>
                						<xsl:for-each select="@*[not(local-name()='id')]">
                							<xsl:value-of select="concat(' ',name(.),' : ',.)"/>
                						</xsl:for-each>                                				
                					</xsl:otherwise>
                				</xsl:choose>
                				<xsl:if test="@*[matches(name(.),'pos$')]">
                				</xsl:if>                                		
                			</xsl:attribute>
                			<xsl:choose>
                				<xsl:when test="descendant::txm:form">
                					<xsl:apply-templates select="txm:form"/>
                				</xsl:when>
                				<xsl:otherwise><xsl:apply-templates/></xsl:otherwise>
                			</xsl:choose>
                		</xsl:otherwise>
                	</xsl:choose>
                                </span><xsl:call-template name="spacing"/></xsl:template>
                
<!--                <xsl:template match="//txm:form">
                                <xsl:apply-templates/>
                </xsl:template>
-->                
	
	<xsl:template match="tei:ex">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="tei:choice">
		<xsl:choose>
			<xsl:when test="tei:corr and tei:sic">
				
					
				<!-- option pop-up -->
				<a class="choice" href="#c{tei:corr/tei:w[1]/@*:id}" name="{tei:corr/tei:w[1]/@*:id}">
					<xsl:apply-templates select="tei:corr"/>
					<span class="pop-up">
						<i>sic&#xa0;:</i>
						<xsl:text> </xsl:text>
						<xsl:for-each select="tei:sic//tei:w">
							<span class="w" id="{@xml:id}">
								<xsl:value-of select="normalize-space(txm:form)"/>
							</span>
							<xsl:if test="following-sibling::*">
								<xsl:text> </xsl:text>
							</xsl:if>
						</xsl:for-each>
					</span>
				</a>
								
				<!-- option inline -->
				
				<!--
					<xsl:apply-templates select="tei:corr"/>
					<xsl:text> (</xsl:text>
				<i>sic&#xa0;:</i>
				<xsl:text> </xsl:text>
				<xsl:for-each select="tei:sic//tei:w">
					<span class="w" id="{@xml:id}">
						<xsl:value-of select="normalize-space(txm:form)"/>
					</span>
					<xsl:if test="following-sibling::*">
						<xsl:text> </xsl:text>
					</xsl:if>
				</xsl:for-each>
				<xsl:text>)</xsl:text>-->
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="spacing"/>
	</xsl:template>

<xsl:template match="tei:del">
	<span class="del">
		<xsl:apply-templates/>
	</span>
</xsl:template>
	
	<xsl:template match="tei:g[@type='initiale']">
		<span class="lettrine">
			<xsl:if test="matches(@rend,'color\(\w+\)')">
				<xsl:attribute name="style">
					<xsl:text>color:</xsl:text>
					<xsl:value-of select="replace(@rend,'^.*color\((\w+)\).*$','$1')"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="tei:supplied">
		<span class="supplied">
				<xsl:choose>
					<xsl:when test="matches(@rend,'middle|final')"/>
					<xsl:otherwise>[</xsl:otherwise>
				</xsl:choose>
			<xsl:apply-templates/>
			<xsl:choose>
				<xsl:when test="matches(@rend,'middle|initial')"/>
				<xsl:otherwise>]</xsl:otherwise>
			</xsl:choose>
		</span>
		<xsl:call-template name="spacing"/>
	</xsl:template>
	
	<xsl:template match="tei:surplus">
		<span class="surplus">
			<xsl:text>(</xsl:text>
			<xsl:apply-templates/>
			<xsl:text>)</xsl:text>
			<span class="pop-up">
				<i>
					<!--<xsl:value-of select="@quantity"/>
				<xsl:text> </xsl:text>-->
					<xsl:choose>
						<xsl:when test="@unit='chars'">lettre</xsl:when>
						<xsl:when test="@unit='sentence'">phrase</xsl:when>
						<xsl:otherwise>mot</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="not(@quantity='1')">s</xsl:if>
					<xsl:text> répété</xsl:text>
					<xsl:if test="not(@quantity='1')">s</xsl:if>
				</i>
			</span>
		</span>
		<xsl:call-template name="spacing"></xsl:call-template>
	</xsl:template>

	<xsl:template name="spacing">
		<xsl:choose>
			<xsl:when test="$inputtype='xmltxm'">
				<xsl:call-template name="spacing-xmltxm"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="spacing-xmlw"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="spacing-xmlw">
		<xsl:choose>
			<xsl:when test="ancestor::tei:w"/>
			<xsl:when test="following::tei:w[1][matches(.,'^\s*[.,)\]]+\s*$')]"/>			
			<xsl:when test="matches(.,'^\s*[(\[‘]+$|\w(''|’)\s*$')"></xsl:when>
			<xsl:when test="position()=last() and (ancestor::tei:choice or ancestor::tei:supplied[not(@rend='multi_s')])"></xsl:when>
			<xsl:when test="following-sibling::*[1][self::tei:note]"></xsl:when>
			<xsl:when test="following::tei:w[1][matches(.,'^\s*[:;!?]+\s*$')]">
				<xsl:text>&#xa0;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text> </xsl:text>
			</xsl:otherwise>
		</xsl:choose>                
	</xsl:template>

	<!--<xsl:template name="spacing-xmltxm">
		<xsl:choose>
			<xsl:when test="ancestor::tei:w"/>
			<xsl:when test="matches(descendant::txm:ana[@type='#aggl'][1],'fgmt')"></xsl:when>
			<xsl:when test="following::tei:w[1][matches(descendant::txm:form[1],'^[.,)\]]+$')]"/>			
			<xsl:when test="matches(descendant::txm:form[1],'^[(\[‘]+$|\w(''|’)$')"></xsl:when>
			<xsl:when test="position()=last() and (ancestor::tei:choice or ancestor::tei:supplied[not(@rend='multi_s')])"></xsl:when>
			<xsl:when test="following-sibling::*[1][self::tei:note]"></xsl:when>
			<xsl:when test="following::tei:w[1][matches(descendant::txm:form[1],'^[:;!?]+$')]">
				<xsl:text>&#xa0;</xsl:text>
			</xsl:when>
			<!-\- patch txm:form imbriqué -\->
			<xsl:when test="matches(descendant::txm:form[1]/txm:form,'^[(\[‘]+$|\w(''|’)$')"></xsl:when>
			<xsl:otherwise>
				<xsl:text> </xsl:text>
			</xsl:otherwise>
		</xsl:choose>                
	</xsl:template>-->
	
	<xsl:template name="spacing-xmltxm">
		<xsl:choose>
			<xsl:when test="ancestor::tei:w"/>
			<xsl:when test="(parent::tei:sic|parent::tei:corr|parent::tei:surplus) and position()=last()"/>
			<!--<xsl:when test="self::tei:w and matches(descendant::txm:ana[@type='#rend'][1],'elision')">’</xsl:when>-->
			<xsl:when test="self::tei:w and matches(descendant::txm:ana[@type='#rend'][1],'fgmt')"></xsl:when>
			<xsl:when test="self::tei:w and matches(descendant::txm:ana[@type='#aggl'][1],'fgmt')"></xsl:when>
			<xsl:when test="following::tei:w[1][matches(descendant::txm:form[1],'^[.,)\]]+$')] and not(ancestor::tei:note)"></xsl:when>			
			<xsl:when test="matches(descendant::txm:form[last()],'^[(\[‘]+$|\w(''|’)$')"></xsl:when>
			<xsl:when test="position()=last() and (ancestor::tei:choice or ancestor::tei:supplied[not(@rend='multi_s')])"></xsl:when>
			<xsl:when test="following::*[1][self::tei:note] and not(ancestor::tei:note)"></xsl:when>
			<xsl:when test="following::tei:w[1][matches(descendant::txm:form[1],'^[:;!?]+$')] and not(ancestor::tei:note)">
				<xsl:text>&#xa0;</xsl:text>
			</xsl:when>
			<!-- patch txm:form imbriqué -->
			<xsl:when test="matches(descendant::txm:form[last()]/txm:form,'^[(\[‘]+$|\w(''|’)$')"></xsl:when>
			<xsl:when test="parent::tei:quote and position()=last()"></xsl:when>
			<xsl:when test="self::text() and matches(.,'[\(''’]\s*$')"></xsl:when>
			<xsl:when test="following-sibling::node()[1][self::text() and matches(.,'^\s*[.,\)\]]')]"></xsl:when>
			<xsl:when test="self::tei:w and following-sibling::node()[1][self::text()[matches(.,'^-$')]]"></xsl:when>
			<xsl:otherwise>
				<xsl:text> </xsl:text>
			</xsl:otherwise>
		</xsl:choose>                
	</xsl:template>

                
</xsl:stylesheet>
