<?xml version="1.0"?>
<xsl:stylesheet xmlns:edate="http://exslt.org/dates-and-times"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:tei="http://www.tei-c.org/ns/1.0" 
	xmlns:txm="http://textometrie.org/1.0"
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:xd="http://www.pnp-software.com/XSLTdoc"
                exclude-result-prefixes="#all" version="2.0">
                
	<xd:doc type="stylesheet">
		<xd:short>
			This stylesheet is designed for TXM XTZ import module to create 
			HTML editions of corpus texts. This stylesheet should be used at 
			"4-edition" step and must be accompanied by 2-default-pager.xsl. 
			See TXM User Manual for more details 
			(http://textometrie.ens-lyon.fr/spip.php?rubrique64)
		</xd:short>
		<xd:detail>
			This stylesheet is free software; you can redistribute it and/or
			modify it under the terms of the GNU Lesser General Public
			License as published by the Free Software Foundation; either
			version 3 of the License, or (at your option) any later version.
			
			This stylesheet is distributed in the hope that it will be useful,
			but WITHOUT ANY WARRANTY; without even the implied warranty of
			MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
			Lesser General Public License for more details.
			
			You should have received a copy of GNU Lesser Public License with
			this stylesheet. If not, see http://www.gnu.org/licenses/lgpl.html
		</xd:detail>
		<xd:author>Alexei Lavrentiev alexei.lavrentev@ens-lyon.fr</xd:author>
		<xd:copyright>2017, CNRS / UMR 5317 IHRIM (CACTUS research group)</xd:copyright>
	</xd:doc>
                
                
                
	<xsl:output method="xml" encoding="UTF-8" omit-xml-declaration="no" indent="no"/>
	
	<!-- <xsl:output method="xml" encoding="UTF-8" omit-xml-declaration="no" indent="no"  doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/> -->
	
                
                <xsl:strip-space elements="*"/>
	                
	<xsl:param name="pagination-element">pb</xsl:param>
	
	<!-- Set "colonne" to use column numbers as TXM page identifiers. Any other value will use standard page count -->
	<xsl:param name="page-numbering"/>
	
	<xsl:variable name="word-element">
		<xsl:choose>
			<xsl:when test="//tei:c//txm:form">c</xsl:when>
			<xsl:otherwise>w</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="page-number-adjust" as="xs:integer">
		<xsl:choose>
			<xsl:when test="//tei:c//txm:form">1</xsl:when>
			<xsl:otherwise>2</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	

                <xsl:variable name="inputtype">
                	<xsl:choose>
                		<xsl:when test="//tei:w//txm:form">xmltxm</xsl:when>
                		<xsl:otherwise>xmlw</xsl:otherwise>
                	</xsl:choose>
                </xsl:variable>
	
	<xsl:variable name="filename">
		<xsl:analyze-string select="document-uri(.)" regex="^(.*)/([^/]+)\.[^/.]+$">
			<xsl:matching-substring>
				<xsl:value-of select="regex-group(2)"/>
			</xsl:matching-substring>
		</xsl:analyze-string>
	</xsl:variable>
                
                <xsl:template match="/">
                	<html>
                		<head>
                			<title><xsl:choose>
                				<xsl:when test="//tei:text/@id"><xsl:value-of select="//tei:text[1]/@id"/></xsl:when>
                				<xsl:otherwise><xsl:value-of select="$filename"/></xsl:otherwise>
                			</xsl:choose></title>
                			<meta http-equiv="Content-Type" content="text/html;charset=UTF-8"/>
                			<link rel="stylesheet" media="all" type="text/css" href="css/txm.css" />
                		</head>
                			<xsl:apply-templates select="descendant::tei:text"/>
                	</html>
                </xsl:template>

	<xsl:template match="tei:text">
		<body>
			<xsl:if test="$word-element='w'">
				<a class="txm-page" title="1"  next-word-id="w_0"/>
				<div class="metadata-page">
					<!--<img src="http://bfm.ens-lyon.fr/local/cache-vignettes/L166xH100/siteon0-bb432.png" style="position:absolute;left:-10px;top:-5px;height:50px;width:83px" alt="BFM"/>-->
					<xsl:if test="@auteur and not(matches(@auteur,'nonym'))">
						<h2><xsl:value-of select="@auteur"/></h2>
					</xsl:if>
					<h1><xsl:choose>
						<xsl:when test="@titre"><xsl:value-of select="@titre"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="@id"/></xsl:otherwise>
					</xsl:choose></h1>
					<xsl:if test="@datecompolibre">
						<h3>
							<xsl:text>(</xsl:text>
							<xsl:value-of select="normalize-space(@datecompolibre)"/>
							<xsl:text>)</xsl:text>
						</h3>
					</xsl:if>
					<h3>Transcription facsimilaire</h3>
					<xsl:if test="ancestor::tei:TEI/tei:teiHeader//tei:ab[@type='how_to_cite']">
						<p><i>Pour citer ce texte :</i> <br/>
							<xsl:value-of select="ancestor::tei:TEI/tei:teiHeader//tei:ab[@type='how_to_cite']/tei:bibl"/></p>
					</xsl:if>
					
					<br/>
					<h2>Métadonnées :</h2>
					<table>
						<xsl:for-each select="@*[not(matches(name(),'textorder'))]">
							<xsl:sort select="name()"/>
							<tr>
								<td><xsl:value-of select="name()"/></td>
								<td><xsl:value-of select="."/></td>
							</tr>
						</xsl:for-each>
					</table>
				</div>
				
			</xsl:if>
			<xsl:apply-templates/>
			
			<xsl:variable name="page_id"><xsl:value-of select="count(descendant::*[local-name()=$pagination-element])"/></xsl:variable>
			
			<xsl:if test="//tei:note[not(@place='inline') and not(matches(@type,'intern|auto|lemmatisation'))][count(preceding::*[local-name()=$pagination-element]) = $page_id]">
				<xsl:text>&#xa;</xsl:text>
				<br/>
				<br/>			
				<span style="display:block;border-top-style:solid;border-top-width:1px;border-top-color:gray;padding-top:5px">                                                
					<xsl:for-each select="//tei:note[count(preceding::*[local-name()=$pagination-element]) = $page_id]">
						<xsl:variable name="note_count"><xsl:value-of select="count(preceding::tei:note) + 1"/></xsl:variable>
						<!--<p><xsl:value-of select="$note_count"/>. <a href="#noteref_{$note_count}" name="note_{$note_count}">[<xsl:value-of select="preceding::tei:cb[1]/@xml:id"/>, l. <xsl:value-of select="preceding::tei:lb[1]/@n"/>]</a><xsl:text> </xsl:text> <xsl:value-of select="."/></p>-->
						<span class="footnote">
							<span style="position:absolute;left:-30px"><a href="#noteref_{$note_count}" name="note_{$note_count}"><xsl:value-of select="$note_count"/></a>. </span>
							<xsl:apply-templates mode="#current"/>
						</span>                                                                
					</xsl:for-each></span><xsl:text>&#xa;</xsl:text>                                                                
				
			</xsl:if>
			
			
		</body>
	</xsl:template>
	
	
                <xsl:template match="*" mode="#all">
                                <xsl:choose>
                                	<xsl:when test="descendant::tei:p|descendant::tei:ab">
                                		<div>
                                			<xsl:call-template name="addClass"/>
                                			<xsl:apply-templates/></div>
                                		<xsl:text>&#xa;</xsl:text>
                                	</xsl:when>
                                	<xsl:otherwise><span>
                                		<xsl:call-template name="addClass"/>
                                		<xsl:if test="self::tei:add[@del]">
                                			<xsl:attribute name="title"><xsl:value-of select="@del"/></xsl:attribute>
                                		</xsl:if>
                                		<xsl:apply-templates mode="#current"/></span>
                                	<xsl:call-template name="spacing"/>
                                	</xsl:otherwise>
                                </xsl:choose>
                </xsl:template>
                
                <xsl:template match="@*|processing-instruction()|comment()">
                                <!--<xsl:copy/>-->
                </xsl:template>
                
<!--                <xsl:template match="comment()">
                                <xsl:copy/>
                </xsl:template>
-->                
                <xsl:template match="text()">
                                <xsl:value-of select="normalize-space(replace(.,'''','’'))"/>
                	<xsl:if test="following-sibling::node()">
                		<xsl:call-template name="spacing"/>
                	</xsl:if>
                </xsl:template>
	
	<xsl:template match="text()" mode="facs">
		<!--<xsl:variable name="document"><xsl:copy-of select="/"></xsl:copy-of></xsl:variable>-->
		<!--<xsl:variable name="lb-n">
			<xsl:value-of select="preceding::tei:milestone[@unit='lb-facs'][1]/@n"/>
		</xsl:variable>-->
		<!--<xsl:variable name="lb-n-adjust">
			<xsl:number count="text()[contains(.,'||')]" from="tei:lb"/>
		</xsl:variable>-->
		<xsl:variable name="lb-n">
			<xsl:choose>
				<xsl:when test="ancestor::tei:w//tei:lb">
					<xsl:value-of select="ancestor::tei:w//tei:lb[1]/@n"/>
				</xsl:when>
				<xsl:otherwise>NaN</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="page-break-pattern" as="element()">
			<xsl:choose>
				<xsl:when test="ancestor::tei:w//*[local-name()=$pagination-element]">
					<with-page>
						<xsl:apply-templates select="ancestor::tei:w//*[local-name()=$pagination-element][1]"/>
						<!--<xsl:text>XXX</xsl:text>-->
					</with-page>
				</xsl:when>
				<xsl:otherwise><no-page/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="color">
			<xsl:choose>
				<xsl:when test="matches(ancestor::tei:w//txm:form//tei:g[@type='initiale']/@rend,'color\(\w+\)')">
					<xsl:value-of select="replace(ancestor::tei:w//txm:form//tei:g[@type='initiale']/@rend,'^.*color\((\w+)\).*$','$1')"/>
				</xsl:when>
				<xsl:otherwise>black</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:analyze-string select="." regex="‹([^›]+)›|\|\||\{{([^\}}]*)\}}|\[[^\]]*\]">
			<xsl:matching-substring>
				<xsl:choose>
					<xsl:when test="matches(.,'‹[^›]+›')">
						<span class="ex"><xsl:value-of select="regex-group(1)"></xsl:value-of></span>
					</xsl:when>
					<xsl:when test="matches(.,'\|\|')">
						<xsl:if test="$page-break-pattern[self::with-page]">
							<xsl:copy-of select="$page-break-pattern/node()"></xsl:copy-of>
						</xsl:if>
						<br/>
						<xsl:if test="matches($lb-n,'[05]\]?$')">
							<span class="verselinenumber"><xsl:value-of select="$lb-n"/></span>
						</xsl:if>
					</xsl:when>
					<xsl:when test="matches(.,'\{([^}]*)\}')">
						<span class="lettrine">
							<xsl:if test="not($color='black')">
								<xsl:attribute name="style">
									<xsl:value-of select="concat('color:',$color)"/>
								</xsl:attribute>
							</xsl:if>
							<xsl:value-of select="regex-group(2)"/>
						</span>
					</xsl:when>
					<xsl:when test="matches(.,'\[([^\]]*)/([^\]]*)\]')">
						<xsl:analyze-string select="." regex="\[([^\]]*)/([^\]]*)\]">
							<xsl:matching-substring>
								<span class="del"><xsl:value-of select="regex-group(1)"/></span>
								<span class="add"><xsl:value-of select="regex-group(2)"/></span>
							</xsl:matching-substring>
						</xsl:analyze-string>						
					</xsl:when>
				</xsl:choose>
			</xsl:matching-substring>
			<xsl:non-matching-substring>
				<xsl:call-template name="deglutinations">
					<xsl:with-param name="string">
						<xsl:value-of select="."/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:non-matching-substring>
		</xsl:analyze-string>
	</xsl:template>
                
	<xsl:template name="deglutinations">
		<xsl:param name="string"/>
		<xsl:analyze-string select="$string" regex="__?\??">
			<xsl:matching-substring><xsl:text> </xsl:text></xsl:matching-substring>
			<xsl:non-matching-substring><xsl:value-of select="translate(.,'*#','')"/></xsl:non-matching-substring>
		</xsl:analyze-string>
	</xsl:template>
                
                <xsl:template name="addClass">
                	<xsl:attribute name="class">
                		<xsl:value-of select="local-name(.)"/>
                		<xsl:if test="@type"><xsl:value-of select="concat('-',@type)"/></xsl:if>
                		<xsl:if test="@subtype"><xsl:value-of select="concat('-',@subtype)"/></xsl:if>
                		<xsl:if test="@rend"><xsl:value-of select="concat('-',@rend)"/></xsl:if>
                	</xsl:attribute>                	
                </xsl:template>
                
                <xsl:template match="tei:p">
                	<xsl:variable name="pN" as="xs:integer">
                		<xsl:value-of select="@n"/>
                	</xsl:variable>
                	<xsl:choose>
                		<xsl:when test="$pN lt 13">
                			<p>
                				<xsl:call-template name="addClass"/>
                				<span class="verselinenumber"><span class="numbering">
                					<xsl:value-of select="concat('§ ',@n)"/>
                				</span></span>
                				<br/>
                				<xsl:apply-templates/>
                			</p>
                		</xsl:when>
                		<xsl:when test="$pN eq 13">
                			<p class="note-inline">La transcription facsimilaire n’est disponible que pour les douze premiers paragraphes du texte.</p>
                		</xsl:when>
                		<xsl:otherwise>
                			<xsl:apply-templates select="descendant::tei:pb"></xsl:apply-templates>
                		</xsl:otherwise>
                	</xsl:choose>
                	<xsl:text>&#xa;</xsl:text>
                </xsl:template>
	
	
	<xsl:template match="tei:ab[@type='strophe']">
		<span class="ab-strophe-alexis-dipl"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="tei:head">
		<!--<xsl:choose>
			<xsl:when test="parent::tei:div/parent::tei:body">
				<h2>
					<xsl:call-template name="addClass"/>
					<xsl:if test="matches(@xml:lang,'^fra?$')">
						<xsl:text>[</xsl:text>
					</xsl:if>
					<xsl:apply-templates/>
					<xsl:if test="matches(@xml:lang,'^fra?$')">
						<xsl:text>]</xsl:text>
					</xsl:if>
				</h2>		
			</xsl:when>
			<xsl:otherwise/>
		</xsl:choose>-->
		
	</xsl:template>
	
	<xsl:template match="tei:gap">
		<span class="gap">
			<xsl:if test="@quantity and @unit">
				<xsl:attribute name="title"><xsl:value-of select="concat(@quantity,' ',@unit)"/></xsl:attribute>
			</xsl:if>
			<xsl:text>[...]</xsl:text>
		</span>
		<xsl:call-template name="spacing"/>
	</xsl:template>
                
	<xsl:template match="tei:lb">
		<xsl:variable name="lbcount">
			<xsl:choose>
				<xsl:when test="ancestor::tei:ab"><xsl:number from="tei:ab" level="any"/></xsl:when>
				<xsl:when test="ancestor::tei:p"><xsl:number from="tei:p" level="any"/></xsl:when>
				<xsl:otherwise>999</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="@rend='hyphen(-)'"><span class="hyphen">-</span></xsl:if>
		<xsl:if test="@rend='hyphen(=)'"><span class="hyphen">=</span></xsl:if>
		<!--<xsl:if test="ancestor::tei:w and not(contains(@rend,'hyphen'))"><span class="hyphen-added">-</span></xsl:if>-->
		<xsl:if test="not($lbcount=1) or preceding-sibling::node()[matches(.,'\S')]"><br/><xsl:text>&#xa;</xsl:text></xsl:if>
		<xsl:if test="@n and not(@rend='prose')">
			<xsl:choose>
				<xsl:when test="matches(@n,'[05]\]?$')">
					<!--<a title="{@n}" class="verseline" style="position:relative"> </a>-->
					<!--<span class="verseline"><span class="verselinenumber"><xsl:value-of select="@n"/></span></span>-->
					<span class="verselinenumber"><xsl:value-of select="@n"/></span>
					
				</xsl:when>
				<xsl:when test="matches(@n,'[^0-9]')">
					<!--<a title="{@n}" class="verseline" style="position:relative"> </a>-->
					<!--<span class="verseline"><span class="verselinenumber"><xsl:value-of select="@n"/></span></span>-->
					<span class="verselinenumber"><xsl:value-of select="@n"/></span>
				</xsl:when>
				<xsl:otherwise>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	
	
	
	<!-- Page breaks -->                
	<xsl:template match="*[local-name()=$pagination-element]">
		
		<xsl:variable name="next-word-position" as="xs:integer">
			<xsl:choose>
				<xsl:when test="following::*[local-name()=$word-element]">
					<xsl:value-of select="count(following::*[local-name()=$word-element][1]/preceding::*[local-name()=$word-element])"/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="next-pb-position" as="xs:integer">
			<xsl:choose>
				<xsl:when test="following::*[local-name()=$pagination-element]">
					<xsl:value-of select="count(following::*[local-name()=$pagination-element][1]/preceding::*[local-name()=$word-element])"/>
				</xsl:when>
				<xsl:otherwise>999999999</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="next-word-id">
			<xsl:choose>
				<xsl:when test="$next-pb-position - $next-word-position = 999999999">w_<xsl:value-of select="$filename"/>_999999999</xsl:when>
				<xsl:when test="$next-pb-position &gt; $next-word-position"><xsl:value-of select="following::*[local-name()=$word-element][1]/@id"/></xsl:when>
				<xsl:otherwise>w_0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		
		<xsl:variable name="editionpagetype">
			<xsl:choose>
				<xsl:when test="ancestor::tei:ab">editionpageverse</xsl:when>
				<xsl:otherwise>editionpage</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="pagenumber">
			<!--<xsl:choose>
				<xsl:when test="@n"><xsl:value-of select="@n"/></xsl:when>
				<xsl:when test="@facs"><xsl:value-of select="substring-before(@facs,'.')"/></xsl:when>
				<xsl:otherwise>[NN]</xsl:otherwise>
			</xsl:choose>-->
			<xsl:analyze-string select="@facs" regex="lyonbm_pa77-(z?_?\d+[abcd])">
				<xsl:matching-substring><xsl:value-of select="regex-group(1)"/></xsl:matching-substring>
			</xsl:analyze-string>
		</xsl:variable>
		
		<xsl:variable name="page_id"><xsl:value-of select="count(preceding::*[local-name()=$pagination-element])"/></xsl:variable>
		
<!--		<xsl:if test="//tei:note[not(@place='inline') and not(matches(@type,'intern|auto|lemmatisation'))][following::*[local-name()=$pagination-element][1][count(preceding::*[local-name()=$pagination-element]) = $page_id]]">
			<xsl:text>&#xa;</xsl:text>
			<br/>
			<br/>			
			<span style="display:block;border-top-style:solid;border-top-width:1px;border-top-color:gray;padding-top:5px">                                                
				<xsl:for-each select="//tei:note[following::*[local-name()=$pagination-element][1][count(preceding::*[local-name()=$pagination-element]) = $page_id]]">
					<xsl:variable name="note_count"><xsl:value-of select="count(preceding::tei:note) + 1"/></xsl:variable>
					<!-\-<p><xsl:value-of select="$note_count"/>. <a href="#noteref_{$note_count}" name="note_{$note_count}">[<xsl:value-of select="preceding::tei:cb[1]/@xml:id"/>, l. <xsl:value-of select="preceding::tei:lb[1]/@n"/>]</a><xsl:text> </xsl:text> <xsl:value-of select="."/></p>-\->
					<span class="footnote">
						<span style="position:absolute;left:-30px"><a href="#noteref_{$note_count}" name="note_{$note_count}"><xsl:value-of select="$note_count"/></a>. </span>
						<xsl:apply-templates mode="#current"/>
					</span>                                                                
				</xsl:for-each></span><xsl:text>&#xa;</xsl:text>                                                                
			
		</xsl:if>-->
		
		
		<xsl:text>&#xa;</xsl:text>
		<br/><xsl:text>&#xa;</xsl:text>
		
		<xsl:choose>
			<xsl:when test="$page-numbering='colonne'"><a class="txm-page" title="{substring-after(@xml:id,'col_')}" next-word-id="{$next-word-id}"/></xsl:when>
			<xsl:otherwise><a class="txm-page" title="{count(preceding::*[local-name()=$pagination-element]) + $page-number-adjust}" next-word-id="{$next-word-id}"/></xsl:otherwise>
		</xsl:choose>
		
		
		<span class="{$editionpagetype}"> &lt;<xsl:value-of select="$pagenumber"/>&gt; </span><xsl:text>&#xa;</xsl:text>
		<xsl:variable name="n">
			<xsl:value-of select="concat('^',@n,'$')"/>
		</xsl:variable>
		
		<span class="runningtitle">
			<xsl:choose>
				<xsl:when test="@n='1'"/>
				<xsl:when test="following::tei:div[@type='épisode'][1]/preceding::tei:pb[1][matches(@n,$n)]">
					<!--					<xsl:text>1. </xsl:text>-->
					<xsl:value-of select="following::tei:div[@type='épisode'][1]/tei:head"/>
				</xsl:when>
				<xsl:when test="ancestor::tei:div[@type='épisode']">
					<!--<xsl:text>2. (</xsl:text>
					<xsl:value-of select="@n"/>
					<xsl:text> - </xsl:text>
					<xsl:value-of select="following::tei:div[@type='épisode'][1]/preceding::tei:pb[1]/@n"/>
					<xsl:text>) </xsl:text>-->
					<xsl:value-of select="ancestor::tei:div[@type='épisode']/tei:head"/>
				</xsl:when>
				<xsl:otherwise>
					<!--<xsl:text>3. </xsl:text>-->
					<xsl:value-of select="preceding::tei:div[@type='épisode'][1]/tei:head"/>
				</xsl:otherwise>
			</xsl:choose>
		</span><br/><xsl:text>&#xa;</xsl:text>
		<xsl:if test="preceding::tei:p[@n='13']">
			<p class="note-inline">La transcription facsimilaire n’est disponible que pour les douze premiers paragraphes du texte.</p>
		</xsl:if>
	</xsl:template>
	
	<!-- Notes -->
	<xsl:template match="tei:note">
		<!--<span style="color:violet"> [<b>Note :</b> <xsl:apply-templates/>] </span>-->
		<xsl:choose>
			<xsl:when test="@place='inline'">
				<span class="noteinline">
					<xsl:text>(</xsl:text>
					<xsl:apply-templates/>
					<xsl:text>)</xsl:text>
				</span>
			</xsl:when>
			<xsl:otherwise>
<!--				<xsl:variable name="note_count"><xsl:value-of select="count(preceding::tei:note) + 1"/></xsl:variable>
				<xsl:variable name="note_content">
					<xsl:choose>
						<xsl:when test="descendant::txm:form">
							<xsl:for-each select="descendant::txm:form">						
								<xsl:value-of select="."/>
								<xsl:if test="not(matches(following::txm:form[1],'^[.,\)]')) and not(matches(.,'^\S+[''’]$|^[‘\(]$'))">
									<xsl:text> </xsl:text>
								</xsl:if>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise><xsl:value-of select="normalize-space(.)"/></xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<a title="{$note_content}" class="noteref" href="#{@*:id}" name="ref_{@*:id}">[<xsl:number count="tei:note" level="any"/>]</a>
-->				<xsl:call-template name="spacing"/> 
				<xsl:if test="@type='sic' and descendant::tei:lb">
					<xsl:if test="matches(following-sibling::tei:w[1]/txm:form,'^[.,:;!?]+$')">
						<xsl:apply-templates select="following-sibling::tei:w[1]">
							<xsl:with-param name="movepunct">yes</xsl:with-param>
						</xsl:apply-templates>
					</xsl:if>
					<br/>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="tei:bibl">
		<span class="noteref" title="{normalize-space(.)}">[•]</span>
	</xsl:template>
	
	<xsl:template match="a[@class='txmpageref']">
		<xsl:copy-of select="."/>
	</xsl:template>
	
	<xsl:template match="tei:choice" mode="#all">
		<xsl:choose>
			<xsl:when test="tei:corr and tei:sic">
				<span class="w" id="{tei:corr[1]/@id}">
					<xsl:apply-templates select="tei:sic" mode="#current"/>
				</span>
			</xsl:when>
			<xsl:otherwise><xsl:apply-templates mode="#current"/></xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="spacing"/>
	</xsl:template>
	
	<xsl:template match="tei:supplied">
		<span class="supplied">
			<xsl:choose>
				<xsl:when test="matches(@rend,'middle|final')"/>
				<xsl:otherwise>[</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates/>
			<xsl:choose>
				<xsl:when test="matches(@rend,'middle|initial')"/>
				<xsl:otherwise>]</xsl:otherwise>
			</xsl:choose>
		</span>
		<xsl:call-template name="spacing"/>
	</xsl:template>
	
	
	<xsl:template match="tei:w">
		<span class="w">
			<xsl:choose>
				<xsl:when test="descendant::tei:c//txm:form">
					<xsl:apply-templates select="descendant::tei:c"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test="@*:id">
						<xsl:attribute name="id"><xsl:value-of select="@*:id"/></xsl:attribute>
					</xsl:if>
					<xsl:attribute name="title">
						<xsl:if test="descendant::txm:form">
							<xsl:text>norm : </xsl:text>
							<xsl:value-of select="normalize-space(descendant::txm:form)"/>
							<xsl:text> ; </xsl:text>
						</xsl:if>
						<xsl:for-each select="@*[not(matches(local-name(.),'id'))]">
							<xsl:value-of select="concat(name(.),' : ',.,' ; ')"/>
						</xsl:for-each>
						<xsl:if test="descendant::txm:ana">	
							<xsl:for-each select="descendant::txm:ana[not(@type='#facs')]">
								<xsl:value-of select="concat(substring-after(@type,'#'),' : ',.,' ; ')"/>
							</xsl:for-each>
						</xsl:if>
					</xsl:attribute>
					<xsl:call-template name="word-content"></xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</span><xsl:call-template name="spacing"/>
	</xsl:template>
	
	<xsl:template name="word-content">
		<xsl:choose>
			<xsl:when test="descendant::txm:ana[@type='#facs']">
				<xsl:apply-templates select="txm:ana[@type='#facs']" mode="facs"/>
			</xsl:when>
			<xsl:otherwise><xsl:apply-templates/></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="tei:ana[@type='#facs']">
		<xsl:apply-templates mode="facs"/>
	</xsl:template>

	<xsl:template name="spacing">
		<xsl:choose>
			<xsl:when test="$inputtype='xmltxm'">
				<xsl:call-template name="spacing-xmltxm"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="spacing-xmlw"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="spacing-xmlw">
		<xsl:choose>
			<xsl:when test="ancestor::tei:w"/>
			<xsl:when test="following::tei:w[1][matches(.,'^\s*[.,)\]]+\s*$')]"/>			
			<xsl:when test="matches(.,'^\s*[(\[‘]+$|\w(''|’)\s*$')"></xsl:when>
			<xsl:when test="position()=last() and (ancestor::tei:choice or ancestor::tei:supplied[not(@rend='multi_s')])"></xsl:when>
			<xsl:when test="following-sibling::*[1][self::tei:note]"></xsl:when>
			<xsl:when test="following::tei:w[1][matches(.,'^\s*[:;!?]+\s*$')]">
				<xsl:text>&#xa0;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text> </xsl:text>
			</xsl:otherwise>
		</xsl:choose>                
	</xsl:template>

	<!--<xsl:template name="spacing-xmltxm">
		<xsl:choose>
			<xsl:when test="ancestor::tei:w"/>
			<xsl:when test="following::tei:w[1][matches(descendant::txm:form[1],'^[.,)\]]+$')]"/>			
			<xsl:when test="matches(descendant::txm:form[1],'^[(\[‘]+$|\w(''|’)$')"></xsl:when>
			<xsl:when test="position()=last() and (ancestor::tei:choice or ancestor::tei:supplied[not(@rend='multi_s')])"></xsl:when>
			<xsl:when test="following-sibling::*[1][self::tei:note]"></xsl:when>
			<xsl:when test="following::tei:w[1][matches(descendant::txm:form[1],'^[:;!?]+$')]">
				<xsl:text>&#xa0;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text> </xsl:text>
			</xsl:otherwise>
		</xsl:choose>                
	</xsl:template>-->

	<xsl:template name="spacing-xmltxm">
		<xsl:choose>
			<xsl:when test="self::tei:w and matches(descendant::txm:ana[@type='#ana'][1],'agglCert_low')">&#x2009;</xsl:when>
			<xsl:when test="self::tei:w and matches(descendant::txm:ana[@type='#rend'][1],'aggl|simple')"></xsl:when>
			<xsl:when test="ancestor::tei:w"/>
			<xsl:when test="ancestor::tei:sic|ancestor::tei:corr"/>
			<!--<xsl:when test="self::tei:w and matches(descendant::txm:ana[@type='#rend'][1],'elision')">’</xsl:when>-->
			<xsl:when test="self::tei:w and matches(descendant::txm:ana[@type='#rend'][1],'fgmt')"></xsl:when>
			<xsl:when test="self::tei:w and matches(descendant::txm:ana[@type='#aggl'][1],'fgmt')"></xsl:when>
			<xsl:when test="following::tei:w[1][matches(descendant::txm:form[1],'^[.,)\]]+$')] and not(ancestor::tei:note)"></xsl:when>			
			<xsl:when test="matches(descendant::txm:form[1],'^[(\[‘]+$|\w(''|’)$')"></xsl:when>
			<xsl:when test="position()=last() and (ancestor::tei:choice or ancestor::tei:supplied[not(@rend='multi_s')])"></xsl:when>
			<xsl:when test="following::*[1][self::tei:note] and not(ancestor::tei:note)"></xsl:when>
			<xsl:when test="following::tei:w[1][matches(descendant::txm:form[1],'^[:;!?]+$')] and not(ancestor::tei:note)">
				<xsl:text>&#xa0;</xsl:text>
			</xsl:when>
			<!-- patch txm:form imbriqué -->
			<xsl:when test="matches(descendant::txm:form[1]/txm:form,'^[(\[‘]+$|\w(''|’)$')"></xsl:when>
			<xsl:when test="parent::tei:quote and position()=last()"></xsl:when>
			<xsl:when test="self::text() and matches(.,'[\(''’]\s*$')"></xsl:when>
			<xsl:when test="following-sibling::node()[1][self::text() and matches(.,'^\s*[.,\)\]]')]"></xsl:when>
			<xsl:when test="self::tei:w and following-sibling::node()[1][self::text()[matches(.,'^-$')]]"></xsl:when>
			<xsl:otherwise>
				<xsl:text> </xsl:text>
			</xsl:otherwise>
		</xsl:choose>                
	</xsl:template>
	

                
</xsl:stylesheet>
