<?xml version="1.0"?>
<xsl:stylesheet xmlns:edate="http://exslt.org/dates-and-times"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:tei="http://www.tei-c.org/ns/1.0" 
	xmlns:txm="http://textometrie.org/1.0"
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:xd="http://www.pnp-software.com/XSLTdoc"
                exclude-result-prefixes="#all" version="2.0">
                
	<xd:doc type="stylesheet">
		<xd:short>
			This stylesheet is designed for TXM XTZ import module to create 
			HTML editions of corpus texts. This stylesheet should be used at 
			"4-edition" step and must be accompanied by 2-default-pager.xsl. 
			See TXM User Manual for more details 
			(http://textometrie.ens-lyon.fr/spip.php?rubrique64)
		</xd:short>
		<xd:detail>
			This stylesheet is free software; you can redistribute it and/or
			modify it under the terms of the GNU Lesser General Public
			License as published by the Free Software Foundation; either
			version 3 of the License, or (at your option) any later version.
			
			This stylesheet is distributed in the hope that it will be useful,
			but WITHOUT ANY WARRANTY; without even the implied warranty of
			MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
			Lesser General Public License for more details.
			
			You should have received a copy of GNU Lesser Public License with
			this stylesheet. If not, see http://www.gnu.org/licenses/lgpl.html
		</xd:detail>
		<xd:author>Alexei Lavrentiev alexei.lavrentev@ens-lyon.fr</xd:author>
		<xd:copyright>2017, CNRS / UMR 5317 IHRIM (CACTUS research group)</xd:copyright>
	</xd:doc>
                
                
                
	<xsl:output method="xml" encoding="UTF-8" omit-xml-declaration="no" indent="no"/>
	
	<!-- <xsl:output method="xml" encoding="UTF-8" omit-xml-declaration="no" indent="no"  doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/> -->
	
                
                <xsl:strip-space elements="*"/>
	                
	<xsl:param name="pagination-element">pb</xsl:param>
	
	<!-- Set "colonne" to use column numbers as TXM page identifiers. Any other value will use standard page count -->
	<xsl:param name="page-numbering"/>
	
	<xsl:variable name="word-element">
		<xsl:choose>
			<xsl:when test="//tei:c//txm:form">c</xsl:when>
			<xsl:otherwise>w</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="page-number-adjust" as="xs:integer">
		<xsl:choose>
			<xsl:when test="//tei:c//txm:form">1</xsl:when>
			<xsl:otherwise>2</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	

                <xsl:variable name="inputtype">
                	<xsl:choose>
                		<xsl:when test="//tei:w//txm:form">xmltxm</xsl:when>
                		<xsl:otherwise>xmlw</xsl:otherwise>
                	</xsl:choose>
                </xsl:variable>
	
	<xsl:variable name="filename">
		<xsl:analyze-string select="document-uri(.)" regex="^(.*)/([^/]+)\.[^/.]+$">
			<xsl:matching-substring>
				<xsl:value-of select="regex-group(2)"/>
			</xsl:matching-substring>
		</xsl:analyze-string>
	</xsl:variable>
                
                <xsl:template match="/">
                	<html>
                		<head>
                			<title><xsl:choose>
                				<xsl:when test="//tei:text/@id"><xsl:value-of select="//tei:text[1]/@id"/></xsl:when>
                				<xsl:otherwise><xsl:value-of select="$filename"/></xsl:otherwise>
                			</xsl:choose></title>
                			<meta http-equiv="Content-Type" content="text/html;charset=UTF-8"/>
                			<link rel="stylesheet" media="all" type="text/css" href="css/txm.css" />
                		</head>
                			<xsl:apply-templates select="descendant::tei:text"/>
                	</html>
                </xsl:template>

	<xsl:template match="tei:text">
		<body>
			<xsl:if test="$word-element='w'">
				<a class="txm-page" title="1"  next-word-id="w_0"/>
				<div class="metadata-page">
					<!--<img src="http://bfm.ens-lyon.fr/local/cache-vignettes/L166xH100/siteon0-bb432.png" style="position:absolute;left:-10px;top:-5px;height:50px;width:83px" alt="BFM"/>-->
					<xsl:if test="@auteur and not(matches(@auteur,'nonym'))">
						<h2><xsl:value-of select="@auteur"/></h2>
					</xsl:if>
					<h1><xsl:choose>
						<xsl:when test="@titre"><xsl:value-of select="@titre"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="@id"/></xsl:otherwise>
					</xsl:choose></h1>
					<xsl:if test="@datecompolibre">
						<h3>
							<xsl:text>(</xsl:text>
							<xsl:value-of select="normalize-space(@datecompolibre)"/>
							<xsl:text>)</xsl:text>
						</h3>
					</xsl:if>
					<h3>Images du manuscrit par colonne</h3>
					<xsl:if test="ancestor::tei:TEI/tei:teiHeader//tei:ab[@type='how_to_cite']">
						<p><i>Pour citer ce texte :</i> <br/>
							<xsl:value-of select="ancestor::tei:TEI/tei:teiHeader//tei:ab[@type='how_to_cite']/tei:bibl"/></p>
					</xsl:if>
					
					<br/>
					<h2>Métadonnées :</h2>
					<table>
						<xsl:for-each select="@*[not(matches(name(),'textorder'))]">
							<xsl:sort select="name()"/>
							<tr>
								<td><xsl:value-of select="name()"/></td>
								<td><xsl:value-of select="."/></td>
							</tr>
						</xsl:for-each>
					</table>
				</div>
				
			</xsl:if>
			<xsl:apply-templates select="descendant::tei:pb"/>
			
			
		</body>
	</xsl:template>
	
	
	
	
	<!-- Page breaks -->                
	<xsl:template match="*[local-name()=$pagination-element]">
		
		<xsl:variable name="next-word-position" as="xs:integer">
			<xsl:choose>
				<xsl:when test="following::*[local-name()=$word-element]">
					<xsl:value-of select="count(following::*[local-name()=$word-element][1]/preceding::*[local-name()=$word-element])"/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="next-pb-position" as="xs:integer">
			<xsl:choose>
				<xsl:when test="following::*[local-name()=$pagination-element]">
					<xsl:value-of select="count(following::*[local-name()=$pagination-element][1]/preceding::*[local-name()=$word-element])"/>
				</xsl:when>
				<xsl:otherwise>999999999</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="next-word-id">
			<xsl:choose>
				<xsl:when test="$next-pb-position - $next-word-position = 999999999">w_<xsl:value-of select="$filename"/>_999999999</xsl:when>
				<xsl:when test="$next-pb-position &gt; $next-word-position"><xsl:value-of select="following::*[local-name()=$word-element][1]/@id"/></xsl:when>
				<xsl:otherwise>w_0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		
		<xsl:variable name="editionpagetype">
			<xsl:choose>
				<xsl:when test="ancestor::tei:ab">editionpageverse</xsl:when>
				<xsl:otherwise>editionpage</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="pagenumber">
			<!--<xsl:choose>
				<xsl:when test="@n"><xsl:value-of select="@n"/></xsl:when>
				<xsl:when test="@facs"><xsl:value-of select="substring-before(@facs,'.')"/></xsl:when>
				<xsl:otherwise>[NN]</xsl:otherwise>
			</xsl:choose>-->
			<xsl:analyze-string select="@facs" regex="lyonbm_pa77-(z?_?\d+[abcd])">
				<xsl:matching-substring><xsl:value-of select="regex-group(1)"/></xsl:matching-substring>
			</xsl:analyze-string>
		</xsl:variable>
		
		<xsl:variable name="page_id"><xsl:value-of select="count(preceding::*[local-name()=$pagination-element])"/></xsl:variable>
		
<xsl:text>&#xa;</xsl:text>
		
		<xsl:choose>
			<xsl:when test="$page-numbering='colonne'"><a class="txm-page" title="{substring-after(@xml:id,'col_')}" next-word-id="{$next-word-id}"/></xsl:when>
			<xsl:otherwise><a class="txm-page" title="{count(preceding::*[local-name()=$pagination-element]) + $page-number-adjust}" next-word-id="{$next-word-id}"/></xsl:otherwise>
		</xsl:choose>
		
		
		<span class="{$editionpagetype}"> &lt;<xsl:value-of select="$pagenumber"/>&gt; </span><!--<br/>--><xsl:text>&#xa;</xsl:text>
		<xsl:variable name="n">
			<xsl:value-of select="concat('^',@n,'$')"/>
		</xsl:variable>
		
		<span class="runningtitle">
			<xsl:choose>
				<xsl:when test="@n='1'"/>
				<xsl:when test="following::tei:div[@type='épisode'][1]/preceding::tei:pb[1][matches(@n,$n)]">
					<!--					<xsl:text>1. </xsl:text>-->
					<xsl:value-of select="following::tei:div[@type='épisode'][1]/tei:head"/>
				</xsl:when>
				<xsl:when test="ancestor::tei:div[@type='épisode']">
					<!--<xsl:text>2. (</xsl:text>
					<xsl:value-of select="@n"/>
					<xsl:text> - </xsl:text>
					<xsl:value-of select="following::tei:div[@type='épisode'][1]/preceding::tei:pb[1]/@n"/>
					<xsl:text>) </xsl:text>-->
					<xsl:value-of select="ancestor::tei:div[@type='épisode']/tei:head"/>
				</xsl:when>
				<xsl:otherwise>
					<!--<xsl:text>3. </xsl:text>-->
					<xsl:value-of select="preceding::tei:div[@type='épisode'][1]/tei:head"/>
				</xsl:otherwise>
			</xsl:choose>
		</span><br/><xsl:text>&#xa;</xsl:text>		
			<img
				src="{@facs}"
				id="txm_image" alt="Le fac-similé de cette page n'est pas accessible"
				onLoad="viewer.toolbarImages='images/icons';viewer.onload=viewer.toolbar;new viewer({{image: this, frame: ['100%','100%']}});"/>
		
		
		
		
	</xsl:template>
	
<!--	<xsl:template match="tei:w">
		<span class="w">
			<xsl:choose>
				<xsl:when test="descendant::tei:c//txm:form">
					<xsl:apply-templates select="descendant::tei:c"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test="@*:id">
						<xsl:attribute name="id"><xsl:value-of select="@*:id"/></xsl:attribute>
					</xsl:if>
					<xsl:attribute name="title">
						<xsl:if test="descendant::txm:form">
							<xsl:text>norm : </xsl:text>
							<xsl:value-of select="normalize-space(descendant::txm:form)"/>
							<xsl:text> ; </xsl:text>
						</xsl:if>
						<xsl:for-each select="@*[not(matches(local-name(.),'id'))]">
							<xsl:value-of select="concat(name(.),' : ',.,' ; ')"/>
						</xsl:for-each>
						<xsl:if test="descendant::txm:ana">	
							<xsl:for-each select="descendant::txm:ana[not(@type='#facs')]">
								<xsl:value-of select="concat(substring-after(@type,'#'),' : ',.,' ; ')"/>
							</xsl:for-each>
						</xsl:if>
					</xsl:attribute>
					<xsl:call-template name="word-content"></xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</span><xsl:call-template name="spacing"/>
	</xsl:template>
-->	
                
</xsl:stylesheet>
